function useAudio(audioState, details) {

  const audioPlayNum = ref(0)

  const pointErrorFun = (error) => {
    const record = deepCopy(details.value)
    record.mainChannel = record.channelList ? record.channelList[0] : {}
    const secondChannel = record.channelList ? record.channelList[1] : {}
    record.secondId = secondChannel ? secondChannel.channelId || '' : ''
    record.errorAudio = error

    playVideoErrorPoint(pointData(record), !!record.traceId)
  }

  let audioEvent = {
    duration: [],
    time: [],
    play: [],
    pause: [],
    error: [],
    ended: [],
  }

  const start = () => {
    audioEvent.duration = []
    audioEvent.time = []
    audioEvent.play = []
    audioEvent.pause = []
    audioEvent.error = []
    audioEvent.ended = []

    const audioElList = document.querySelectorAll('.preview-audio-player, .preview-audio-player-cover')
    audioElList.forEach((item, _) => {
      const dataId = item.getAttribute('data-id')
      const item_audio = item.querySelector('[class^="audio-block"]')
      const audioStyleTotalTime = item.querySelector('.audio-durtion')
      const audioProgress = item.querySelector('.audio-progressed')
      const durationFun = function () {
        jqHtml(audioStyleTotalTime, { type: 'set', str: transTime(item_audio.duration) })
      }
      item_audio.addEventListener('durationchange', durationFun)

      audioEvent.duration.push(durationFun)

      const timeFun = function () {
        jqHtml(audioStyleCurTime, { type: 'set', str: transTime(item_audio.currentTime) })
        if (audioProgress) {
          audioProgress.style.width = `${(item_audio.currentTime / item_audio.duration) * 100}%`
        }
      }

      item_audio.addEventListener('timeupdate', timeFun)

      audioEvent.time.push(timeFun)

      const audioStylePlay = item.querySelector('.audio-play-icon')
      const audioStylePause = item.querySelector('.audio-pause-icon')

      const audioStyleCurTime = item.querySelector('.audio-current')

      const errorFun = function () {}
      const endedFun = function () {
        jqHtml(audioStyleCurTime, { type: 'set', str: '00:00' })
      }

      item_audio.addEventListener('error', errorFun)
      item_audio.addEventListener('ended', endedFun)

      audioEvent.error.push(errorFun)
      audioEvent.ended.push(endedFun)


      const playFun = function () {
        if (item_audio) {
          audioPlayNum.value += 1
          item_audio.play()
          audioStylePlay.style.display = 'none'
          audioStylePause.style.display = 'block'

          try {
            sendNative('jsCall_currentPageOperate', {
              operateType: '10'
            })
          } catch (e) { }

          audioElList.forEach(el => {
            const dataIds = el.getAttribute('data-id')
            if (dataIds != dataId) {
              const item_audios = el.querySelector('[class^="audio-block"]')
              if (item_audios) {
                const audioStylePlays = el.querySelector('.audio-play-icon')
                const audioStylePauses = el.querySelector('.audio-pause-icon')
                item_audios.pause()
                audioStylePlays.style.display = 'block'
                audioStylePauses.style.display = 'none'
              }
            }
          })
        }
      }

      const pauseFun = function () {
        if (item_audio) {
          item_audio.pause()
          audioStylePause.style.display = 'none'
          audioStylePlay.style.display = 'block'
        }
      }

      audioStylePlay.addEventListener('click', playFun)
      audioStylePause.addEventListener('click', pauseFun)

      audioEvent.play.push(playFun)
      audioEvent.pause.push(pauseFun)
    })
  }

  watch(audioState, (val) => {
    if (val) {
      console.log('watch', val)
      const audioElList = document.querySelectorAll('.preview-audio-player, .preview-audio-player-cover')

      audioElList.forEach((item, _) => {
        const audioStylePlay = item.querySelector('.audio-play-icon')
        const audioStylePause = item.querySelector('.audio-pause-icon')

        const item_audio = item.querySelector('[class^="audio-block"]')
        if (item_audio) {
          item_audio.pause()
          audioStylePause.style.display = 'none'
          audioStylePlay.style.display = 'block'
        }
      })
    }
  }, {
    deep: true
  })

  const remove = () => {
    audioPlayNum.value = 0
    const audioElList = document.querySelectorAll('.preview-audio-player, .preview-audio-player-cover')
    audioElList.forEach((item, key) => {
      const audioStylePlay = item.querySelector('.audio-play-icon')
      const audioStylePause = item.querySelector('.audio-pause-icon')
      const item_audio = item.querySelector('[class^="audio-block"]')

      if (item_audio) {
        item_audio.pause()
        audioStylePause.style.display = 'none'
        audioStylePlay.style.display = 'block'
      }

      if  (audioEvent.duration.length) {
        item_audio.removeEventListener('durationchange', audioEvent.duration[key])
      }

      if  (audioEvent.time.length) {
        item_audio.removeEventListener('timeupdate', audioEvent.time[key])
      }

      if  (audioEvent.ended.length) {
        item_audio.removeEventListener('ended', audioEvent.ended[key])
      }

      if  (audioEvent.error.length) {
        item_audio.removeEventListener('error', audioEvent.error[key])
      }

      if  (audioEvent.play.length) {
        audioStylePlay.removeEventListener('click', audioEvent.play[key])
      }

      if  (audioEvent.pause.length) {
        audioStylePause.removeEventListener('click', audioEvent.pause[key])
      }

    })
    audioEvent = {}
  }

  return {
    start,
    remove,
    audioPlayNum
  }
}
