function useEchart() {
  const echartList = ref([])

  const echartRemove = () => {
    echartList.value.forEach(el => {
      if (el && el.dispose) {
        el.dispose()
      }
    })
    echartList.value = []
  }

  const start = (options) => {
    if (options) {
      Object.values(options).forEach((item) => {
        let dom = document.querySelector(`#${item.id}`)
        if (dom) {
          const oldOptions = deepCopy(item.option)
          const type = oldOptions && oldOptions.series ? oldOptions.series[0].type : ''
          const title = oldOptions.title ? oldOptions.title.text || '' : ''
          const isScatter = item.option.series && item.option.series.length === 2
          let yValueName = ''

          if (oldOptions && oldOptions.yAxis) {
            try {
              if (isArray(oldOptions.yAxis)) {
                yValueName = oldOptions.yAxis[0].name
              } else if (isObject(oldOptions.yAxis)) {
                yValueName = oldOptions.yAxis.name
              }
            } catch (e) {

            }
          }
          dom.outerHTML = `<div class="en-echart ${isScatter ? 'scatter' : ''}">${!!title ?
            `<div class="en-echart-title droidSerif-bold">${oldOptions.title.text}</div>` : ''}${!!yValueName
            ? `<div class="en-echart-yname">${yValueName}</div>`
            : ''}<div class="en-echart-map" style="width: 100%; height: ${type === 'pie'
            ? 5
            : 6.29333}rem; margin: 0 auto;" id="${item.id}"></div></div>`
        }
      })
      setTimeout(() => {
        loadFile(
          document,
          {
            src: './js/plugin/echart.min.js',
            tag: 'script',
            type: 'text/javascript',
            defer: 'defer'
          },
          () => {
            loadFile(
              document,
              {
                src: './js/plugin/ecStat.min.js',
                tag: 'script',
                type: 'text/javascript',
                defer: 'defer'
              },
              () => {
                const isDark = document.querySelector('html').getAttribute('dark-mode') === 'true'
                echarts.registerTransform(ecStat.transform.regression)
                Object.values(options).forEach((item) => {
                  let dom = document.querySelector(`#${item.id}`)
                  if (dom) {
                    const type = item.option.series[0].type
                    const isScatter = item.option.series && item.option.series.length === 2
                    const seriesObjSecond = item.option.series ? item.option.series[1] : {}
                    item.option.yAxis = item.option && item.option.yAxis ? item.option.yAxis[0] : {}
                    item.option.yAxis.offset = 0
                    if (isScatter) {
                      item.option.yAxis.nameTextStyle = {}
                      item.option.yAxis.nameTextStyle.align = 'left'
                      item.option.yAxis.nameTextStyle.padding = [ 0, 0, 0, -34 ]
                      delete item.option.yAxis.name
                    } else {
                      delete item.option.yAxis.name
                    }

                    let dom2 = document.querySelector(`#${item.id}`)
                    let chart = echarts.init(dom2, null, {
                      renderer: 'svg',
                      useDirtyRect: false
                    })

                    echartList.value.push(chart)

                    chart.on('finished', function () {
                      changeContentHtmlHeight({ type: '图表' })
                    })

                    delete item.option.title
                    if (isScatter) {   // 是指数回归
                      renderScatter(chart, item)
                    } else {    //  是其他图形
                      const areaStyle = item.option.series[0].areaStyle
                      if (areaStyle) {
                        item.option.xAxis = item.option.xAxis[0]
                      }
                      const pie = type === 'pie' ? {
                        avoidLabelOverlap: false,
                        label: {
                          normal:
                            {
                              position: 'inner',
                              formatter: '{d}%',
                              fontWeight: 'normal',
                              fontSize: `${10 / 37.5}rem`,
                              color: '#fff'
                            }
                        },
                        labelLine: {
                          show: false
                        },
                        tooltip: {
                          trigger: 'item',
                          formatter: '{b}:{c} ({d}%)'
                        }
                      } : {}
                      const options = shallowMerge(item.option, {
                        backgroundColor: isDark ? '#1d1d1d' : '#fff',
                        grid: {
                          containLabel: true,
                          left: '1px',
                          right: '5%',
                          top: type === 'pie' ? '0%' : '6%',
                          bottom: '5%'
                        },
                        dataset: [
                          {
                            source: item.option.dataset ? item.option.dataset[0].source : ''
                          },
                          {
                            transform: {
                              type: 'ecStat:regression',
                              config: {
                                method: 'exponential'
                              }
                            }
                          }
                        ],
                        legend: type === 'pie' ? {
                          left: -5,
                          borderRadius: 0,
                          orient: 'vertical',
                          top: 'center',
                          textStyle: {
                            color: isDark ? '#aaa' : '#222'
                          }
                        } : undefined,
                        series: [
                          shallowMerge(item.option.series[0], {
                            radius: [ '40%', '90%' ],
                            itemStyle: type === 'line' ? {
                              'color': '#ED2800',
                              'lineStyle': {
                                'color': '#ED2800'
                              }
                            } : undefined,
                            center: type === 'pie' ? [ '74%%', '50%' ] : null,
                            symbol: type === 'line' ? 'circle' : type === 'scatter' ? seriesObjSecond.symbol : '',
                            symbolSize: type === 'line' ? '7' : type === 'scatter' ? seriesObjSecond.symbolSize : '',
                            areaStyle: type === 'line' && !!areaStyle ? {
                              color: {
                                type: 'linear',
                                x: 0,
                                y: 0,
                                x2: 0,
                                y2: 1,
                                colorStops: [
                                  {
                                    offset: 0,
                                    color: '#FF917B' // 0% 处的颜色
                                  },
                                  {
                                    offset: 1,
                                    color: 'rgba(183, 29, 38, 0)' // 100% 处的颜色
                                  }
                                ],
                                global: false // 缺省为 false
                              }
                            } : undefined
                          }, pie)
                        ]
                      })
                      try {
                        if (isDark) {
                          if (isArray(options.xAxis)) {
                            options.xAxis[0].nameTextStyle = {}
                            options.xAxis[0].nameTextStyle.color = '#aaa'
                            options.xAxis[0].axisLine = {
                              lineStyle: {
                                color: '#aaa'
                              }
                            }
                          } else if (isObject(options.xAxis)) {
                            options.xAxis.nameTextStyle = {}
                            options.xAxis.nameTextStyle.color = '#aaa'
                            options.xAxis.axisLine = {
                              lineStyle: {
                                color: '#aaa'
                              }
                            }
                          }
                          if (isArray(options.yAxis)) {
                            options.yAxis[0].nameTextStyle = {}
                            options.yAxis[0].nameTextStyle.color = '#aaa'
                            options.yAxis[0].axisLine = {
                              lineStyle: {
                                color: '#aaa'
                              }
                            }
                            options.yAxis[0].splitLine = {
                              lineStyle: {
                                color: '#333'
                              }
                            }
                          } else if (isObject(options.yAxis)) {
                            options.yAxis.nameTextStyle = {}
                            options.yAxis.nameTextStyle.color = '#aaa'
                            options.yAxis.axisLine = {
                              lineStyle: {
                                color: '#aaa'
                              }
                            }
                            options.yAxis.splitLine = {
                              lineStyle: {
                                color: '#333'
                              }
                            }
                          }
                        }
                      } catch (e) {
                      }

                      chart.setOption(options)
                    }
                  }
                })
              }
            )
          }
        )
      }, 10)
    }
  }

  const renderScatter = (chart, item) => {
    const isDark = document.querySelector('html').getAttribute('dark-mode') === 'true'
    const options = shallowMerge(item.option, {
      backgroundColor: isDark ? '#1d1d1d' : '#fff',
      grid: {
        containLabel: true,
        left: '0%',
        top: '15%',
        bottom: '10%'
      },
      dataset: item.option.dataset,
      series: [
        shallowMerge({}, item.option.series[0]),
        shallowMerge(item.option.series[1], {
          labelLayout: { dx: -60, dy: -10 }
        })
      ]
    })
    try {
      if (isDark) {
        if (isArray(options.xAxis)) {
          options.xAxis[0].nameTextStyle = {}
          options.xAxis[0].nameTextStyle.color = '#aaa'
          options.xAxis[0].axisLine = {
            lineStyle: {
              color: '#aaa'
            }
          }
        } else if (isObject(options.xAxis)) {
          options.xAxis.nameTextStyle = {}
          options.xAxis.nameTextStyle.color = '#aaa'
          options.xAxis.axisLine = {
            lineStyle: {
              color: '#aaa'
            }
          }
        }
        if (isArray(options.yAxis)) {
          options.yAxis[0].nameTextStyle = {}
          options.yAxis[0].nameTextStyle.color = '#aaa'
          options.yAxis[0].axisLine = {
            lineStyle: {
              color: '#aaa'
            }
          }
          options.yAxis[0].splitLine = {
            lineStyle: {
              color: '#333'
            }
          }
        } else if (isObject(options.yAxis)) {
          options.yAxis.nameTextStyle = {}
          options.yAxis.nameTextStyle.color = '#aaa'
          options.yAxis.axisLine = {
            lineStyle: {
              color: '#aaa'
            }
          }
          options.yAxis.splitLine = {
            lineStyle: {
              color: '#333'
            }
          }
        }
      }
    } catch (e) {
    }
    chart.setOption(options)
  }

  return {
    start,
    echartRemove
  }
}
