const { ref, reactive, watch } = Vue

const domUtil = new DomUtil('#newsContent')

let audioNoticeEvent = []
let audioTitleElList = []

function trimContentInBlockTagsUsingDOM(html, inlineTags) {
  // 创建一个容器元素来解析HTML字符串
  const container = document.createElement('div')
  jqHtml(container, { type: 'set', str: html })

  // 获取所有块级元素
  const blockTags = container.querySelectorAll('*')

  blockTags.forEach(node => {
    // 检查是否为块级元素
    if (!inlineTags.includes(node.tagName.toLowerCase())) {
      // 遍历其子节点，去除文本节点末尾的空格
      for (let i = node.childNodes.length - 1; i >= 0; i--) {
        const child = node.childNodes[i]
        if (child.nodeType === Node.TEXT_NODE) {
          child.textContent = child.textContent.replace(/\s+$/, '')
        }
      }
    }
  })

  // 返回处理后的HTML字符串
  return jqHtml(container, { type: 'get' })
}

function trimContentFirstUsingDOM(html) {
  // 创建一个容器元素来解析HTML字符串
  const container = document.createElement('div')
  jqHtml(container, { type: 'set', str: html })

  // 获取所有块级元素
  const blockTags = Array.from(container.children).map(child => child)
  blockTags.forEach(node => {
    let firstChild = node.firstChild

    while (firstChild) {
      if (firstChild.nodeType === Node.TEXT_NODE) {
        // 如果是文本节点，去除首行空白
        firstChild.textContent = firstChild.textContent.replace(/^\s+/, '')
        break
      } else if (firstChild.nodeType === Node.ELEMENT_NODE) {
        // 如果是元素节点，继续找其第一个子元素
        firstChild = firstChild.firstChild
      } else {
        // 如果既不是文本节点也不是元素节点，跳出循环
        break
      }
    }
  })

  // 返回处理后的HTML字符串
  return jqHtml(container, { type: 'get' })
}

function clearImgaeLinkStyle(html) {
  // 创建一个容器元素来解析HTML字符串
  const container = document.createElement('div')
  jqHtml(container, { type: 'set', str: html })

  // 获取所有块级元素
  const imageLinkEls = container.querySelectorAll('a[class^="imageLink_"]')
  imageLinkEls.forEach(el => el.setAttribute('style', ''))
  // 返回处理后的HTML字符串

  return jqHtml(container, { type: 'get' })
}

function useEditorContent(details, netstutas, audioState, loadlmageOnlyWifiSwitch, recordTime) {
  const { startImage, remove: removeImage, addPreview } = useImage(details, netstutas, loadlmageOnlyWifiSwitch)
  const { start: startAudio, remove: removeAudio } = useAudio(audioState, details)
  const { start: startEchart, echartRemove } = useEchart()
  const { startSwiper, addSwiper, remove: removeSwiper, elList: swiperList } = useSwiper()
  const { startSwiperPoster, addSwiperPoster, remove: removeSwiperPoster, elList: swiperPosterList } = useSwiperPoster()
  const { initVideo, addVideoList, removeDpVideo } = useVideo()

  const startSwiperText = () => {
    const basicWidth = getTextWidth('Trucks wait to load containers at a container terminal in Rizhao。', {
      fontSize: '0.32rem', whiteSpace: 'nowrap', paddingLeft: '1.06666667rem'
    })
    const swiperText = document.querySelectorAll('#newsContent .en-scroll-text .swiper-txet')
    for (let i = 0; i < swiperText.length; i++) {
      const leftWidth = swiperText[i].parentNode.querySelector('.scroll-text-left').getBoundingClientRect().width
      const rightWidth = document.querySelector('#newsTitle').getBoundingClientRect().width - leftWidth
      const textWidth = swiperText[i].getBoundingClientRect().width
      // const hasLong = textWidth > rightWidth
      // if (hasLong) swiperText[i].style.flex = 1
      const keyframes = document.createElement('style')
      document.head.appendChild(keyframes)
      const keyframesSheet = keyframes.sheet
      const rate = 10 / (rightWidth + basicWidth)
      const firstDuration = rate * textWidth

      // 定义关键帧的样式
      const frameStyles = `0% {transform: translateX(0%);}100% {transform: translateX(calc(${-textWidth}px + 44px));}`
      const frameStyless = `0% {transform: translateX(calc(${rightWidth}px - 12px));}100% {transform: translateX(calc(${-textWidth}px + 44px));}`

      // 添加关键帧到样式表中
      keyframesSheet.insertRule(`@keyframes swiperText${i} { ${frameStyles} }`, 0)
      keyframesSheet.insertRule(`@keyframes swiperTextIn${i} { ${frameStyless} }`, 1)
      swiperText[i].style.animation = `swiperText${i} ${firstDuration}s linear`
      swiperText[i].style.animationDelay = `.5s`
      setTimeout(() => {
        swiperText[i].style.animation = `swiperTextIn${i} ${rate * (rightWidth + textWidth)}s linear infinite`
        swiperText[i].style.animationDelay = `0`
      }, firstDuration * 1000 + 500)
    }
  }

  const startAuidoText = () => {
    const originAudioElList = document.querySelectorAll('.audio-title')
    originAudioElList.forEach(el => {
      const wrapWidth = el.getBoundingClientRect().width
      const textHeight = el.getBoundingClientRect().height
      const text = el.textContent
      const hasCover = el.getAttribute('data-cover') === 'cover'
      const isShortTitle = getTextWidth(text, {
        fontSize: hasCover ? '0.32rem' : '0.4rem',
        fontWeight: hasCover ? 500 : 700,
        lineHeight: hasCover ? '0.42666667rem' : `${17 / 37.5}rem`,
        display: 'inline-block',
        wordBreak: 'break-all',
        width: `${wrapWidth}px`
      }, 'height') <= textHeight
      if (!isShortTitle) {
        audioTitleElList.push(el)
      }
    })
    for (let i = 0; i < audioTitleElList.length; i++) {
      const el = audioTitleElList[i]
      const wrapWidth = el.getBoundingClientRect().width
      const speed = 60
      const contentEl = el.querySelector('.audio-notice-title')
      const contentWidth = contentEl.getBoundingClientRect().width
      let offset = -contentWidth
      let duration = contentWidth / +speed
      contentEl.style.transform = offset ? `translateX(${offset}px)` : ''
      contentEl.style.transitionDuration = `${duration}s`

      function onTransitionEnd() {
        offset = wrapWidth
        duration = 0
        contentEl.style.transform = offset ? `translateX(${offset}px)` : ''
        contentEl.style.transitionDuration = `${duration}s`

        setTimeout(() => {
          offset = -contentWidth
          duration = (contentWidth + wrapWidth) / +speed

          contentEl.style.transform = offset ? `translateX(${offset}px)` : ''
          contentEl.style.transitionDuration = `${duration}s`
        }, 50)

      }

      audioNoticeEvent.push(onTransitionEnd)

      contentEl.addEventListener('transitionend', onTransitionEnd)
    }

  }

  const handleArticleStr = (deleteFirst) => {
    if (!document.querySelector('#newsContent') && window.config.VUE_BASE_NODE === 'dev') {
      changeContentHtmlHeight({ type: 'done-before' })
      if (document.querySelector('.error-block').style.display !== 'block') {
        appBlock(true)
        mobileApp(true)
        startShowArticle = true
        changeContentHtmlHeight({ type: 'done' })
      }

      return
    }
    // console.log(`编辑器内容二次处理开始：${dayjs().format('HH:mm:ss:SSS')} - ${dayjs()
    // .diff(recordTime.value, 'millisecond')} - ${dayjs()
    // .diff(dayjs(firstTime), 'millisecond')}`)
    recordTime.value = dayjs()
    // TODO 这里是把给到的内容格式化-兼容早晚报
    let str = details.value.newsContent.replace(/<img(.*?)src="(.*?)"(.*?)>/g, '<img$1src="" data-src="$2"$3>')
    str = str.replace(/<IMG(.*?)src="(.*?)"(.*?)>/g, '<IMG$1src="" data-src="$2"$3>')
    str = str.replace(/<video(.*?)poster="(.*?)"(.*?)>/g, '<video$1poster="" data-poster="$2"$3>')
    str = str.replace(/<VIDEO(.*?)poster="(.*?)"(.*?)>/g, '<VIDEO$1poster="" data-poster="$2"$3>')
    str = str.replace(/<p>\s*<\/p>/g, '')
    str = str.replace(/[\u200B-\u200D\uFEFF]/g, '')
    str = htmlDecode(str)
    // 这一步去除元素与元素之间的空格
    str = str.replace(/>\s+</g, '><')
    // 这一步去除开头和末尾的空格
    str = str.trim()
    str = clearImgaeLinkStyle(str)
    if (!deleteFirst) {
      str = str.replace(/<br>|<br\/>/g, '')
      str = str.replace(/&nbsp;/g, ' ')

      // 首行空格
      str = trimContentFirstUsingDOM(str)
      // str = str.replace(/<[^>]*>(\s*)/g, function (match, group) {
      //   return '<' + match.substring(1, match.length - group.length)
      // })
      // console.log(str)
      const inlineLevelTags = [ 'span', 'em', 'i', 'b', 'a', 'strong' ]
      // const inlineLevelTags = []
      // 末尾空格判断
      if (inlineLevelTags.length > 0) {
        str = trimContentInBlockTagsUsingDOM(str, inlineLevelTags)
      } else {
        str = str.replace(/(<\w+[^>]*>)\s*(.*?)\s*(<\/\w+>)/g, function (match, openTag, content, closeTag) {
          return openTag + content.trim() + closeTag
        })
      }
    }
    jqHtml('#newsContent', { type: 'set', str })
    const realHtml = jqHtml('#newsContent', { type: 'get' })
    jqHtml('#newsContent', { type: 'set', str: '' })
    domUtil.handleArticleStr(realHtml, (type, option) => {
      if (type === 1) {
        addPreview()
      } else if (type === 2) {
        addVideoList(option)
      } else if (type === 3) {
        addSwiper(option)
      } else if (type === 4) {
        addSwiperPoster(option)
      } else if (type === 5) {
        loadCSS('./css/swiper-bundle.min.css')
      }
    }, details.value, netstutas.value, loadlmageOnlyWifiSwitch.value)

    clearEmptyPel()
    // errorBlock(
    //   './image/content_fail.svg',
    //   '获取内容失败，请重试',
    //   true
    // )
    changeContentHtmlHeight({ type: 'done-before' })
    if (document.querySelector('.error-block').style.display !== 'block') {
      appBlock(true)
      mobileApp(true)
      startShowArticle = true
    }

    // console.log(`数据逻辑处理总共耗时时间：${dayjs().format('HH:mm:ss:SSS')} - ${dayjs()
    // .diff(recordTime.value, 'millisecond')} - ${dayjs()
    // .diff(dayjs(firstTime), 'millisecond')}`)
    recordTime.value = dayjs()

    nextTick(() => {
      startSwiperText()
      startAuidoText()
      if (details.value.newsContentBak && details.value.newsContentBak !== '{}') {
        try {
          startEchart(JSON.parse(details.value.newsContentBak))
        } catch (e) {
        }
      }
      addLinkClick()
      startImage()
      initVideo()
      startAudio()

      nextTick(() => {
        if (swiperList.value.length) { startSwiper() }
        if (swiperPosterList.value.length) { startSwiperPoster() }

        changeContentHtmlHeight({ type: 'done' })
      })
    })
  }

  const addLinkClick = () => {
    const aEl = document.querySelectorAll('#newsContent a')
    for (let i = 0; i < aEl.length; i++) {
      addEventListenerWrap(aEl[i], 'click', (_) => {
        const peopleOrigin = []
        let url = aEl[i].getAttribute('data-href')
        if (peopleOrigin.some(origin => url.includes(origin))) {
          if (!url.includes('isIner=0')) {
            if (url.includes('?')) {
              if (url[url.length - 1] !== '?') {
                url = `${url}&isIner=0`
              } else if (url[url.length - 1] === '?') {
                url = `${url}isIner=0`
              }
            } else {
              url = `${url}?isIner=0`
            }
          }
        }
        try {
          let dataInfo = aEl[i].getAttribute('data-rmrbnative')
          try {
            if (dataInfo) {
              dataInfo = Base64().decode(dataInfo)
              dataInfo = JSON.parse(dataInfo)
            }
          } catch (error) {}

          const inner = dataInfo && (typeof dataInfo === 'undefined'
            ? 'undefined'
            : typeof dataInfo === 'object' && dataInfo.jumpType && dataInfo.jumpType == 'internal')
          console.log(inner)
          console.log(dataInfo)
          if (inner && url) {
            jumpAppInnerFun(dataInfo, url)
          } else if (url) {
            sendNative('jsCall_appInnerLinkMethod', {
              appInnerLink: `rmrbapp://rmrb.app/openwith?type=h5&url=${encodeURIComponent(url)}&skipType=4`
            })
          }
        } catch (e) {}
      })
    }
  }

  const initEditorStr = (deleteFirst) => {
    handleArticleStr(deleteFirst)
  }

  const refreshEditorStr = () => {
    if (window.config.VUE_BASE_NODE === 'dev') {
      document.querySelector('#app').scrollTo({
        top: 0, behavior: 'smooth' // 如果需要平滑滚动，可以添加这个选项
      })
    }
    audioTitleElList.forEach((el, key) => {
      const contentEl = el.querySelector('.audio-notice-title')
      contentEl.removeEventListener('transitionend', audioNoticeEvent[key])
    })
    removeDpVideo()
    removeImage()
    echartRemove()
    removeAudio()
    removeSwiper()
    removeSwiperPoster()
    domUtil.clearHtml()
    changeContentHtmlHeight({ str: '.skeleton-loading' })
    mobileApp(false)
  }

  return {
    initEditorStr, refreshEditorStr
  }
}
