function useVideo() {
  /* 视频预览 */
  const videoPreview = ref([])
  /* 默认视频预览 */
  const defaultVideoPreview = ref([])
  const enPlayerVideoLen = ref(0)
  /* 视频加载数 */
  const videoLoadNum = ref(0)
  /* 视频加载 */
  const videoLoaded = ref(false)
  /* 视频状态 */
  const videoState = reactive({
    currentVideo: {}
  })

  watch(videoLoadNum, (val) => {
    if (val === defaultVideoPreview.value.length) {
      videoLoaded.value = true
    }
  })

  // 每个富文本里面的video加入到数组中
  const addVideoList = (option) => {
    videoPreview.value.push(option.id)
    defaultVideoPreview.value.push({
      id: option.id,
      url: option.src,
      poster: option.poster,
      originId: option.originId,
      isNewspaper: option.isNewspaper,
      rect: {
        top: 0, width: 0, height: 0
      },
      el: null,
      elPatent: null,
      player: null,
      dp: null
    })
  }

  // 初始换每个video标签，转化成 artplayer 播放器
  const startVideo = () => {
    const videoList = document.querySelectorAll('#newsContent .video-player')
    if (videoList.length) {
      videoList.forEach((_, index) => {
        const videoItem = videoList[index]
        const width = videoItem.getBoundingClientRect().width
        const domId = videoItem.getAttribute('id')
        const id = videoItem.getAttribute('data-id')
        /* 视频的宽度 */
        const originWidth = videoItem.getAttribute('data-width') || 0
        /* 视频的高度 */
        const originHeight = videoItem.getAttribute('data-height') || 0
        const record = defaultVideoPreview.value.find((el) => el.id === id)
        let height = isNumber(Number(originWidth)) ? isNaN(Number(originWidth)) || Number(originWidth) === 0
          ? 0
          : Number(width) / (Number(originWidth) / Number(originHeight)) : 0

        let styleHeight = height
        if (!styleHeight) styleHeight = Number(width) / (16 / 9)

        const isGiveWidth = !!height

        videoItem.setAttribute('data-height', `${styleHeight}px`)
        videoItem.style.height = `${styleHeight}px`
        videoItem.parentNode.style.width = `100%`
        videoItem.parentNode.style.height = `${styleHeight}px`

        videoLoadNum.value += 1

        changeContentHtmlHeight({ type: '视频' })

        const player = new videoEnPlayer({
          config: {
            key: index,
            record,
            isGiveWidth,
            videoOptions: {
              originWidth,
              originHeight,
              width,
              height
            }
          },
          callBackFun: {
            ready: (playerWdith, playerHieght, callback) => {
              if (isGiveWidth) return
              const newHeight = !!playerWdith && !!playerHieght ? Number(width) * Number(playerHieght) / Number(
                playerWdith) : 300
              videoItem.setAttribute('data-height', `${newHeight}px`)
              videoItem.style.height = `${newHeight}px`
              videoItem.parentNode.style.width = `100%`
              videoItem.parentNode.style.height = `${newHeight}px`
              callback(newHeight)

              changeContentHtmlHeight({ type: '视频' })
            },
            play: () => {
              const audioElList = document.querySelectorAll('.preview-audio-player, .preview-audio-player-cover')

              audioElList.forEach((item, _) => {
                const audioStylePlay = item.querySelector('.audio-play-icon')
                const audioStylePause = item.querySelector('.audio-pause-icon')

                const item_audio = item.querySelector('[class^="audio-block"]')
                if (item_audio) {
                  item_audio.pause()
                  audioStylePause.style.display = 'none'
                  audioStylePlay.style.display = 'block'
                }
              })
            },
            pauseOhterDp: () => {},
            continueNetwork: () => {
            }
          }

        })

        defaultVideoPreview.value = defaultVideoPreview.value.map((item) => {
          if (item.id === id) {
            enPlayerVideoLen.value += 1
            item.index = index
            item.rect.width = width
            item.rect.height = height
            item.el = videoItem
            item.elPatent = videoItem.parentNode
            item.dp = player.player
            item.player = player
            item.domId = domId
          }
          return item
        })
      })
    }
  }

  // 外层初始调用
  const initVideo = () => {
    if (defaultVideoPreview.value.length > 0) {
      loadFile(document, {
        src: './js/plugin/aliPlayer.min.js', tag: 'script', type: 'text/javascript', defer: 'defer'
      }, () => {
        startVideo()
      })
    }
  }

  // 销毁每个视频 artplayer 播放器
  const removeDpVideo = () => {
    defaultVideoPreview.value = defaultVideoPreview.value.map((el) => {
      if (el.dp) {
        el.dp.pause()
      }
      if (el.player) {
        el.player.destroy()
      }
      el.dp = null
      el.player = null
      return el
    })

    videoLoaded.value = false
    videoLoadNum.value = 0
    enPlayerVideoLen.value = 0
    videoState.currentVideo = {}
    videoPreview.value = []
    defaultVideoPreview.value = []
  }

  return {
    initVideo,
    addVideoList,
    removeDpVideo
  }
}
