dayjs.extend(dayjs_plugin_localizedFormat)
dayjs.extend(dayjs_plugin_relativeTime)

const { onMounted, onUnmounted, toRefs, nextTick, watchEffect, toRef } = Vue

function compareTimeArray(obj1, obj2, key, sort) {
  const val1 = obj1[key]
  const val2 = obj2[key]
  let result = 0
  if (dayjs(val1).isBefore(dayjs(val2))) {
    result = sort === 0 ? -1 : 0
  } else if (dayjs(val1).isAfter(dayjs(val2))) {
    result = sort === 0 ? 0 : -1
  }
  return result
}

const app = Vue.createApp({
  setup() {
    const baseNode = ref(window.config.VUE_BASE_NODE)
    const deviceType = ref(judgTerminal() === 1 ? 'ad' : 'ios')
    const time = ref('')
    const recordTime = ref()
    const channelId = ref()
    const loginTime = ref()
    const statrTime = ref(dayjs())
    const subjectList = ref([])
    const channelList = ref([])
    const suggestedList = ref([])
    const voteOtions = ref([])
    const canSeeBtnOne = ref(true)
    const canSeeBtnTwo = ref(true)
    const hasReadCount = ref(true)
    const networkStatus = ref(1) // 0 无网络 1 wifi 2，3，4，5 无wifi状态
    const networkSwitch = ref(2) // 1 允许 2 不允许
    const browseCnt = ref('0') // 外部音频点击暂停次数
    const audioState = ref(0) // 外部音频点击暂停次数
    const loadlmageOnlyWifiSwitch = ref(window.config.VUE_BASE_NODE === 'dev' ? '2' : '0') // 1 仅wifi加载图片 2 都可以加载图片
    const showClook = ref(false)
    const optionList = ref([])
    const clookStatusSee = ref(false)
    const clookCancelBtnActive = ref(false)
    const clookBtnActive = ref(false)
    const hasHeadLink = ref(false)
    const voteInit = ref(false)
    const isPageLeave = ref(false)
    const hasInit = ref(false)
    const shareOpen = ref(false)
    const isOwer = ref(false)
    const isRmh = ref(null)
    const isNewspaper = ref(null)
    const browseStr = ref('')

    const state = reactive({
      clientHeight: 0,
      appFontSize: 'normalsize',
      // appFontSize: 'Large',
      // appFontSize: 'large',
      // appFontSize: 'small',
      //投票id
      darkMode: darkMode,
      voteId: null,
      relId: null,
      contentId: null,
      sourcePage: '2',
      //环境
      environment: 'sit',
      showShare: false,
      //请求头
      appHeader: shallowMerge({
        system: judgTerminal() === 1 ? 'Android' : 'ios'
      }, window.config.VUE_BASE_HEADER),
      initialRes: {},
      originDataSource: {},
      //此details对接口返回的数据进行了二次改造，属性的添加和属性值的转换
      details: {
        rmhInfo: null,
        author: [],
        newLinkObject: {},
        //投票信息
        voteInfo: {},
        endTimePoint: false,
        yes: {},
        no: {},
        slideShows: {},
        //片头跳转
        headLinkdata: ''
      },
      initClockStatus: false,
      shareNewPoster: true,
      voteState: {
        // status: 1,
        // optionId: '7323',
        status: 0,
        optionId: ''
      },
      creatorID: null,
      curIndex: 0,
      bcIndex: 0,
      Doing: false,
      isLogined: 0, // 0 未登录  1 已登录
      isSub: false,
      isSubClose: false,
      seeEmailSub: false,
      strategy: {},
      emailVal: '',
      deviceId: '',
      userId: '',
      aboutUserName: '',
      agreementURL: '',
      recomList: []
    })
    const timeLine = reactive({
      title: '',
      topicId: '',
      topicType: '',
      pageId: '',
      linkUrl: '',
      slideColor: '#ED2800',
      data: []
    })
    const actieInfo = reactive({
      show: false,
      id: -1,
      title: '',
      type: '',
      linkUrl: '',
      coverUrl: ''
    })

    const {
      initEditorStr,
      refreshEditorStr
    } = useEditorContent(
      toRef(state, 'details'),
      networkStatus,
      audioState,
      loadlmageOnlyWifiSwitch,
      recordTime
    )

    recordTime.value = dayjs()
    changeContentHtmlHeight({ str: '.skeleton-loading' })

    try {
      sendNative('jsCall_currentPageOperate', {
        operateType: '48'
      }, () => {
      })
    } catch (e) {}

    /**
     * @Author      gx12358
     * @DateTime    2024/7/5
     * @lastTime    2024/7/5
     * @description 工具函数
     */
    const errorResponse = () => clearInterval(time.value)
    const removeHtmlStr = (str) => {
      if (!str) return str
      return str.replace(/<br\s*\/?>/g, '')
    }

    function shallowMergeObj(target, ...sources) {
      const newTarget = deepCopy(target)
      sources.forEach(source => {
        for (let key in source) {
          if (source.hasOwnProperty(key)) {
            newTarget[key] = source[key]
          }
        }
      })
      return newTarget
    }

    // 模拟App加载错误
    function changeAppError() {
      console.log(null.replace(/<img(.*?)src="(.*?)"(.*?)>/g, '<img$1src="" data-src="$2"$3>'))
    }

    /**
     * @Author      gx12358
     * @DateTime    2024/7/5
     * @lastTime    2024/7/5
     * @description 主流程
     */
    if (window.config.VUE_BASE_NODE === 'dev') {
      mountedFun(() => {
        if (!window.config.VUE_CONTENT_CONFIG && !window.config.devApp) {
          requestDev()
        }
      })
    } else {
      mountedFun(() => {})
    }

    function mountedFun(callbakc) {
      if (!slow) {
        fast = true
        if (callbakc) callbakc()
      }
    }

    function requestDev(devApp) {
      state.clientHeight = document.documentElement.getBoundingClientRect().height
      clientHeight = state.clientHeight
      time.value = setInterval(() => {
        if (window.config.initLoad) {
          state.darkMode = darkMode
          document.querySelector('#app').style.overflowY = 'auto'
          document
          .querySelector('html')
          .setAttribute('dark-mode', darkMode === 'dark')
          appFontSize = state.appFontSize
          setRemUnit(state.appFontSize)
          // document.documentElement.setAttribute('data-size', state.appFontSize)
          state.environment = window.config.VUE_BASE_HEADER.environment
          // channelId.value = 2038
          state.relId = 500004384175
          state.contentId = 30037827178
          contentId = state.contentId
          clearInterval(time.value)
          setTimeout(() => {
            initData(devApp ? window.config.VUE_CONTENT_CONFIG : {}, state.contentId, devApp)
          }, devApp ? 10 : 0)
        }
      }, 10)
    }

    const requestApp = () => {
      if (window.config.VUE_BASE_NODE === 'dev') {
        requestDev(true)
        return
      }
      document.querySelector('.error-block').style.display = 'none'
      setRemUnit()
      /*config数据是由H5预埋，App加载完成后 app主动传递的方法名请求数据  */
      const config = window.config.VUE_CONTENT_CONFIG
      try {
        const data =
          typeof config === 'object' ? config : JSON.parse(config)
        if (data.dataJson) {
          const dataJson =
            typeof data.dataJson === 'object'
              ? data.dataJson
              : JSON.parse(data.dataJson)
          state.sourcePage = dataJson.sourcePage
          clearInterval(time.value)
          // console.log(`详情接口完成：${dayjs().format('HH:mm:ss:SSS')} - ${dayjs()
          // .diff(recordTime.value, 'millisecond')} - ${dayjs()
          // .diff(firstTime, 'millisecond')}`)
          recordTime.value = dayjs()
          changeContentHtmlHeight({ str: 'body', type: 'init' })

          const netError = dataJson.netError
          contentId = dataJson.contentId
          state.contentId = dataJson.contentId
          channelId.value = dataJson.channelId

          if (netError == 0) {
            // 异步获取App公共信息
            try {
              sendNative('jsCall_getAppPublicInfo', {}, header => {
                // app返回的数据
                const headerObj =
                  typeof header === 'object' ? header : JSON.parse(header)
                state.appHeader = deepCopy(headerObj)
                //通用设备imei
                state.deviceId = state.appHeader.device_id
                state.userId = state.appHeader.userId
                logInfo(state.userId)
                //	App服务协议
                state.agreementURL = state.appHeader.agreementURL
                //0:无网 1:Wi-Fi 2:2G 3:3G 4:4G 5:5G
                // networkStatus.value = state.appHeader.networkStatus
                //prod、sit、dev、uat
                state.environment = state.appHeader.environment
              })
            } catch (e) {

            }

            try {
              getClickStatus(() => {})
            } catch (e) {}

            try {
              // console.log('详情初始数据', data)
              if (data.dataExt) {
                hasAppLoginExtra = true

                const extraData = typeof data.dataExt === 'object'
                  ? data.dataExt
                  : JSON.parse(data.dataExt)
                darkMode = extraData ? extraData.darkMode || darkMode : darkMode
                state.darkMode = darkMode
                document
                .querySelector('html')
                .setAttribute('dark-mode', darkMode === 'dark')
                state.appFontSize = extraData ? extraData.fontSizes : ''
                state.clientHeight = extraData ? extraData.clientHeight : ''
                clientHeight = state.clientHeight
                // document.documentElement.setAttribute('data-size', state.appFontSize)
                appFontSize = state.appFontSize
                setRemUnit(state.appFontSize)
                state.cnsTraceId = extraData ? extraData.cnsTraceId : ''
                state.creatorID = extraData ? extraData.creatorId : ''
                state.isLogined = extraData ? extraData.isLogin : ''
                // 0:无网 1:WiFi 2:2G 3:3G 4:4G 5:5G
                networkStatus.value = extraData ? extraData.networkStatus || 1 : 1
                loadlmageOnlyWifiSwitch.value = extraData && extraData.loadImageOnlyWifiSwitch
                  ? extraData.loadImageOnlyWifiSwitch
                  : '0'
              }
            } catch (e) {
            }

            // 处理详情
            let initialRes = dataJson.responseMap
            initialRes =
              typeof initialRes === 'object'
                ? initialRes
                : JSON.parse(initialRes)
            initData(initialRes, dataJson.contentId)
          } else {
            errorResponse()
            errorBlock(
              './image/no_net.svg',
              '网络出小差了，请检查网络后重试',
              true
            )
          }
        }
      } catch (e) { }
    }
    const initData = async (res, id, devApp) => {
      /**判断是否为本地开发环境，是的话初始化数据，不是的话通过app提供的方法，h5发送数据给app**/
      if (window.config.VUE_BASE_NODE === 'dev') {
        if (devApp || window.config.devApp) {
          const details = res.data ? res.data.length > 0 ? res.data[0] : {} : {}
          hasDetails = true
          handleArticle(details)

          return
        }

        const response = await axiosRequest({
          url: '/content/zh/c/content/detail',
          methot: 'post',
          appStatus: false,
          isMock: true,
          // weakNetwork: true,
          // mockTimeOut: 10,
          //环境
          environment: state.environment,
          //接口前缀
          prefix: '/api/rmrb-bff-display-zh',
          //给接口传的数据
          data: {
            contents: [
              {
                //内容id
                contentId: id,
                relId: state.relId
              }
            ]
          },
          //请求头信息
          headers: state.appHeader
        })
        // console.log(`详情接口完成：${dayjs().format('HH:mm:ss:SSS')} - ${dayjs()
        // .diff(recordTime.value, 'millisecond')} - ${dayjs().diff(dayjs(firstTime), 'millisecond')}`)
        recordTime.value = dayjs()
        if (response.success) {
          if (response.data) {
            const details = response.data.length > 0 ? response.data[0] : {}
            hasDetails = true
            handleArticle(details)
          } else {
            errorResponse()
            errorBlock(
              './image/content_fail.svg',
              '内容找不到了'
            )
          }
        } else {
          errorResponse()
          errorBlock(
            './image/content_fail.svg',
            '获取内容失败，请重试',
            true
          )
        }
      } else {
        if ([ 200, '0' ].includes(res.code) > 0) {
          if (res.data) {
            const details = res.data.length > 0 ? res.data[0] : {}
            hasDetails = true
            // 获取用户登录状态
            if (hasAppLoginExtra) {
              handleArticle(details)
            } else {
              // const nowDate = dayjs()
              // console.log('获取app登录状态开始：')
              try {
                sendNative('jsCall_getAppLoginAuthInfo', {}, res => {
                  // console.log('获取app登录状态结束：', `${dayjs()
                  // .diff(nowDate, 'millisecond')}`)
                  // 获取登录状态响应
                  const loginStatusResponse =
                    typeof res === 'object' ? res : JSON.parse(res)
                  state.creatorID = loginStatusResponse && loginStatusResponse.creatorID
                  state.isLogined =
                    loginStatusResponse && loginStatusResponse.isLogined
                  handleArticle(details)
                })
              } catch (e) { }
            }
          } else {
            errorResponse()
            errorBlock(
              './image/content_fail.svg',
              '内容找不到了'
            )
          }
        } else {
          errorResponse()
          errorBlock(
            './image/content_fail.svg',
            '获取内容失败，请重试',
            true
          )
        }
      }
    }
    const handleArticle = (details) => {
      if (Object.keys(details).length === 0) {
        errorResponse()
        errorBlock(
          './image/content_fail.svg',
          '获取内容失败，请重试'
        )
        return
      }
      contentId = state.contentId
      isRmh.value = !!details.rmhInfo
      isNewspaper.value = details.isNewspaper
      if (!details.rmhInfo) {
        browseCntChange(details)
      }
      state.showShare = true
      state.details = deepCopy(details)
      state.originDataSource = deepCopy(details)
      if (window.config.VUE_BASE_NODE === 'dev') {
        initApp(details)
      } else {
        initApp(details)
        try {
          // H5传递数据至App
          sendNative(
            'jsCall_receiveH5Data',
            { dataSource: '1', dataJson: JSON.stringify(state.originDataSource) },
            () => {
            }
          )
        } catch (e) { }
      }
    }
    const initApp = data => {
      getOthersStatus(data, () => {
        if (data.authorList && data.authorList.length > 0) {
          //authorList：图文【撰稿人，对应p端创建人名称；人民号内容为空】
          const authorList = deepCopy(data.authorList).filter(item => item.authorName) || []
          state.details.author = []
          authorList.forEach(el => {
            if (el.authorName) {
              const modifiedString = el.authorName.replace(/\s+/g, ',')
              const authorNameList = modifiedString.split(',')
              if (authorNameList.length > 1) {
                authorNameList.forEach(name => state.details.author.push(name))
              } else {
                state.details.author.push(el.authorName)
              }
            }
          })
        }

        if (data.newLinkObject && data.newLinkObject.newsTitle) {
          // state.details.newLinkObject.newsTitle = data.newLinkObject.newsTitle.replace(/ /g, '&nbsp;')
          // state.details.newLinkObject.newsTitle = data.newLinkObject.newsTitle.replace(/—/g, '<span class="global-line"></span>')
          hasHeadLink.value = true
        }

        if (data.newsShortTitle) {
          // state.details.newsShortTitle = data.newsShortTitle.replace(/ /g, '&nbsp;')
          // state.details.newsShortTitle = data.newsShortTitle.replace(/—/g, '<span class="global-line"></span>')
        }
        if (data.newsTitle) {
          // state.details.newsTitle = data.newsTitle.replace(/ /g, '&nbsp;')
          // state.details.newsTitle = data.newsTitle.replace(/—/g, '<span class="global-line"></span>')
        }
        if (data.newsDownTitle) {
          // state.details.newsDownTitle = data.newsDownTitle.replace(/—/g, '&mdash;')
          // state.details.newsDownTitle = data.newsDownTitle.replace(/—/g, '<span class="global-line"></span>')
        }
        if (data.newIntroduction) {
          // state.details.newIntroduction = data.newIntroduction.replace(/—/g, '&mdash;')
          // state.details.newIntroduction = data.newIntroduction.replace(/—/g, '<span class="global-line"></span>')
        }

        // 首次发布时间:publishTime
        state.details.publishTime = data.publishTime
          ? dayjs(data.publishTime).format('YYYY年MM月DD HH:mm')
          : ''
        subjectList.value = data.subjectList
          ? data.subjectList.map(el => el.name).filter(el => el)
          : []
        channelList.value = data.channelList
          ? data.channelList.map(el => el.channelName).filter(el => el)
          : []
        // headLinkdata:片头跳转
        state.details.headLinkdata =
          data.newLinkObject && data.newLinkObject.headLinkdata
            ? data.newLinkObject.headLinkdata
            : ''

        shareOpen.value = state.details.shareInfo ? state.details.shareInfo.shareOpen == 1 : false

        hasInit.value = true
        if (pageError) {
          changeAppError()
        }
        initEditorStr(isNewspaper.value)
      })
    }
    const getClickStatus = (callback) => {
      if (window.config.VUE_BASE_NODE === 'dev') {
      } else {
        try {
          sendNative(
            'jsCall_getArticleDetailBussinessData',
            {
              //写死为1
              getSharePosterShowNew: '1',
              getLoadImageOnlyWifiSwitch: '1',
              getPlayVideoOnCellularNetworkSwitch: '1'
            },
            res => {
              let objNvtSwt = res ? res : {}
              let lastObjNvtSwt =
                typeof objNvtSwt === 'object'
                  ? objNvtSwt
                  : JSON.parse(objNvtSwt)
              // loadlmageOnlyWifiSwitch.value = lastObjNvtSwt.loadImageOnlyWifiSwitch
              state.shareNewPoster = lastObjNvtSwt.sharePosterShowNew == '1'
              networkSwitch.value =
                lastObjNvtSwt.playVideoOnCellularNetworkSwitch // 蜂窝数据播放  1 允许  2 不允许

              callback && callback()
            }
          )
        } catch (e) { }
      }
    }
    const browseCntChange = (details) => {
      if (details.viewCount) {
        browseStr.value = ''
        browseCnt.value = details.viewCount ? `${handleNum(details.viewCount)}` : '0'
        if (browseCnt.value && ![ '0', 'undefined', 'null' ].includes(browseCnt.value)) {
          hasReadCount.value = true
          browseStr.value = `浏览量${browseCnt.value}`
        } else {
          hasReadCount.value = false
        }
      } else {
        hasReadCount.value = false
      }
      nextTick(() => {
        if (
          document.querySelector('.skeleton-loading').classList.contains('active') &&
          !document.querySelector('#app').classList.contains('fixed')
        ) {
          changeContentHtmlHeight()
        }
      })
    }
    const getOthersStatus = (data, callBack) => {
      if (data.voteInfo) {
        if (state.isLogined == 1) {
          if (data.voteInfo && data.voteInfo.voteId) {
            handleVoteData(data)
            voteStatus(data.voteInfo.voteId, null, () => {
              setTimeout(() => {
                nextTick(() => {
                  if (document.querySelector('.skeleton-loading').classList.contains('active')) {
                    changeContentHtmlHeight()
                  }
                })
              }, 100)
            })
          }
        } else {
          handleVoteData(data)
          voteInit.value = true
          handleVoteList()
          setTimeout(() => {
            nextTick(() => {
              if (document.querySelector('.skeleton-loading').classList.contains('active')) {
                changeContentHtmlHeight()
              }
            })
          }, 100)
        }
      }
      if (data.rmhInfo) {
        // 人民号信息
        state.details.rmhInfo = data.rmhInfo
        //人民号信息人民号姓名存在则赋值给details.rmhName
        state.details.rmhName = data.rmhInfo.rmhName
          ? data.rmhInfo.rmhName
          : ''
        //rmhId：人民号id
        state.details.rmhId = data.rmhInfo.rmhId ? data.rmhInfo.rmhId : ''
        //rmhId：人民号加v头像
        state.details.authIcon = data.rmhInfo.authIcon ? data.rmhInfo.authIcon : ''
        //userId：用户id
        state.details.userId = data.rmhInfo.userId ? data.rmhInfo.userId : ''
        //userType：用户类型 1：普通用户，2：创作者 3：矩阵号 4:运营子账号 5:内容源账号
        state.details.userType = data.rmhInfo.userType
          ? data.rmhInfo.userType
          : ''
        //rmhHeadUrl：人民号头像
        state.details.rmhHeadUrl = data.rmhInfo.rmhHeadUrl
          ? data.rmhInfo.rmhHeadUrl
          : ''
        //rmhDesc：描述
        state.details.rmhDesc = data.rmhInfo.rmhDesc
          ? data.rmhInfo.rmhDesc
          : ''

        if (state.isLogined == 1) {
          // 已登录
          if (window.config.VUE_BASE_NODE === 'dev') {
            showClook.value = true
          } else {
            clookStatus(true) // 查"关注"状态 ， 更新按钮上的文字
          }
        } else {
          showClook.value = true
        }
      }

      if (data.topicInfo) {
        timeLine.title = data.topicInfo.title
        timeLine.topicId = data.topicInfo.topicId
        timeLine.topicType = data.topicInfo.topicType
        timeLine.pageId = data.topicInfo.pageId
        timeLine.linkUrl = data.topicInfo.linkUrl
        timeLine.slideColor = data.topicInfo.slideColor || '#ED2800'

        if (data.topicInfo.slideShows) {
          timeLine.data = data.topicInfo.slideShows.filter(item => item.publishTime && item.newsTitle).map(item => {
            item.dateTimeStr = dayjs(item.publishTime).format('MM月DD日 HH:mm')
            return item
          }).sort((a, b) => compareTimeArray(a, b, 'publishTime', 1))
        }
      }

      if (data.activityInfos) {
        Object.assign(actieInfo, data.activityInfos ? data.activityInfos[0] : {})
        if (actieInfo.title) { actieInfo.show = true }
      }

      if (callBack) callBack()
    }

    /**
     * @Author      gx12358
     * @DateTime    2024/7/5
     * @lastTime    2024/7/5
     * @description 页面交互
     */
    const reload = () => {
      // 页面重新加载
      errorStatus = false
      clearData()
      pageReloadChange()
      loadingBlock(true)
      changeContentHtmlHeight({ str: '.skeleton-loading' })

      if (window.config.VUE_BASE_NODE === 'dev') {
        initData({}, state.contentId)
      } else {
        try {
          sendNative(
            'jsCall_currentPageOperate',
            {
              operateType: '22'
            },
            (res) => {}
          )
        } catch (e) {

        }
      }
    }
    // 跳转人民号主页
    const skipCustomerNumberPage = () => {
      if (window.config.VUE_BASE_NODE === 'dev') {
      } else {
        if (state.details.rmhInfo.banControl == 1) {
          // 该账号已封禁，不予访问
          toast('该账号已封禁，不予访问')
          return
        }

        window.config.VUE_APP_LOGIN = ''
        try {
          isPageLeave.value = true
          sendNative(
            'jsCall_appInnerLinkMethod',
            {
              appInnerLink: `rmrbapp://rmrb.app/openwith?type=owner_page&subType=${state.details.userType}&contentId=${state.details.userId}&creatorId=${state.details.rmhId}&skipType=1`
            }
          )
        } catch (e) { isPageLeave.value = false }
      }

    }
    // 点击协议提示字跳转到协议页面，调取App内链方法
    const inptClick = () => {
      if (window.config.VUE_BASE_NODE === 'dev') {
      } else {
        try {
          sendNative('jsCall_appInnerLinkMethod', {
            //参考conflence内链文档
            //skipType =3跳转H5页面链接(APP内部打开)
            appInnerLink: `rmrbapp://rmrb.app/openwith?type=h5&url=${state.agreementURL}&skipType=3`
          })
        } catch (e) { }
      }
    }
    // 片头跳转
    const moreInformationClick = () => {
      if (window.config.VUE_BASE_NODE === 'dev') {
        console.log(state.details.newLinkObject)
      } else {
        // let linkUrl = ''
        // const jumpUrl = state.details.newLinkObject.jumpUrl
        // const newsObjectType = state.details.newLinkObject.newsObjectType
        // if (jumpUrl) {
        //   linkUrl = `rmrbapp://rmrb.app/openwith?type=h5&url=${encodeURIComponent(jumpUrl)}&skipType=3`
        // } else {
        //   switch (newsObjectType) {
        //     case 8:
        //       break
        //   }
        // }
        console.log(state.details.newLinkObject)
        try {
          sendNative(
            'jsCall_receiveH5Data',
            {
              dataSource: '6',
              dataJson: JSON.stringify(state.details.newLinkObject)
            }
          )
        } catch (e) { }
      }

    }
    // 分享
    const openShare = (sharePlatform) => {
      const shareInfo = state.details.shareInfo
      if (shareInfo && shareInfo.shareUrl) {
        try {
          sendNative(
            //H5调用此方法，启动客户端分享弹窗
            'jsCall_openAppShare',
            {
              //分享类型:1.文字类型分享  2.网页类型分享
              type: '2',
              //是否显示分享:1 显示分享按钮 0 不显示
              isShowShare: 1,
              //分享标题（当type为2时可用）
              title: shareInfo.shareTitle,
              //分享描述（当type为2时可用 ）
              description: shareInfo.shareSummary,
              //分享链接（当type为2时可用 ）
              webpageUrl: shareInfo.shareUrl,
              //分享图标链接（当type为2时可用，分享小icon需小于64k ）
              imageUrl: shareInfo.shareCoverUrl,
              //分享的内容Id：活动ID、视频ID等
              contentId: state.details.newsId,
              //1.facebook  2.twitter 3.微信 4.微信朋友圈 5.微博 6.系统分享 7. 弹框App全分享 8.海报分享
              sharePlatform
            },
            () => { }
          )
        } catch (e) {
        }
      }
    }
    // 跳转时间轴专题
    const openMoreTimeLine = () => {
      sendNative(
        'jsCall_appInnerLinkMethod',
        {
          appInnerLink: `rmrbapp://rmrb.app/openwith?type=topic&subType=h5&pageId=${timeLine.pageId}&url=${encodeURIComponent(
            timeLine.linkUrl)}&skipType=1`
        }
      )
    }
    // 活动跳转
    const openActiveLink = () => {
      try {
        sendNative(
          'jsCall_appInnerLinkMethod',
          {
            appInnerLink: `rmrbapp://rmrb.app/openwith?type=h5&url=${encodeURIComponent(actieInfo.linkUrl)}&skipType=3`
          }
        )
      } catch (e) {

      }
    }

    /**
     * @Author      gx12358
     * @DateTime    2024/7/5
     * @lastTime    2024/7/5
     * @description 关注交互
     */
    const clookBtn = () => {
      // 人民号关注
      if (window.config.VUE_BASE_NODE === 'dev') {
        if (clookBtnActive.value) {
          return
        }
        clookBtnActive.value = true
        setTimeout(() => {
          showClook.value = false
          clookStatusSee.value = false
          clookBtnActive.value = false
          followTypePoint({
            type: 1,
            followPDUserId: state.details.rmhId,
            followUserName: state.details.rmhName,
            channelId: channelId.value,
            newsType: state.details.newsType,
            newsId: state.details.newsId,
            newsTitle: state.details.newsTitle,
            sceneId: state.details.sceneId,
            itemId: state.details.itemId,
            subSceneId: state.details.subSceneId,
            cnsTraceId: state.cnsTraceId,
            isNewspaper: isNewspaper.value,
            duration: dayjs().diff(statrTime.value, 'second')
          })
        }, 1000)
        return
      }
      if (clookBtnActive.value) {
        return
      }
      if (state.isLogined == 1) {
        clookCancelBtnActive.value = false
        clookBtnActive.value = true
      }
      getUserLoginStatus(loginId => {
        if (loginId == 0) {
          //  0 未登录
          setAppLogin()
          checkAppLoginStatu('follow')
          return
        } else {
          // 1 已登录 直接走 关注接口
          showClook.value = false
          clookBtnHandel(1)
        }
      })
    }
    // 人民号取消关注
    const clookCancelBtn = () => {
      if (window.config.VUE_BASE_NODE === 'dev') {
        if (clookCancelBtnActive.value) {
          return
        }
        clookCancelBtnActive.value = true
        setTimeout(() => {
          showClook.value = true
          clookStatusSee.value = true
          clookCancelBtnActive.value = false
          followTypePoint({
            type: 0,
            cancelFollowPDUseId: state.details.rmhId,
            cancelFollowUserName: state.details.rmhName,
            channelId: channelId.value,
            newsType: state.details.newsType,
            newsId: state.details.newsId,
            newsTitle: state.details.newsTitle,
            sceneId: state.details.sceneId,
            itemId: state.details.itemId,
            subSceneId: state.details.subSceneId,
            cnsTraceId: state.cnsTraceId,
            isNewspaper: isNewspaper.value,
            duration: dayjs().diff(statrTime.value, 'second')
          })
        }, 1000)
        return
      }
      if (clookCancelBtnActive.value) {
        return
      }
      if (state.isLogined == 1) {
        clookBtnActive.value = false
        clookCancelBtnActive.value = true
      }
      getUserLoginStatus(loginId => {
        if (loginId == 0) {
          //  0 未登录
          setAppLogin()
          checkAppLoginStatu('follow')
          return
        } else {
          // 1 已登录 直接走 取消关注接口
          showClook.value = true
          clookBtnHandel(0)
        }
      })
    }
    // 人民号关注、取消关注接口调用
    const clookBtnHandel = async (status) => {
      if (window.config.VUE_BASE_NODE === 'dev') {
        const response = await axiosRequest({
          url: '/interact/zh/c/attention/operation',
          methot: 'post',
          appStatus: false,
          environment: state.environment,
          prefix: '/api/rmrb-interact',
          data: {
            status,
            attentionUserId: `${state.details.userId}`,
            attentionUserType: `${state.details.userType}`,
            attentionCreatorId: `${state.details.rmhId}`
          },
          headers: state.appHeader,
          showError: false
        })
        if (response.success) {
        }
      } else {
        try {
          sendNative(
            'jsCall_callAppService',
            {
              method: 'post',
              url: '/api/rmrb-interact/interact/zh/c/attention/operation',
              parameters: {
                status,
                attentionUserId: `${state.details.userId}`,
                attentionUserType: `${state.details.userType}`,
                attentionCreatorId: `${state.details.rmhId}`
              }
            },
            res => {
              const response = typeof res === 'object' ? res : JSON.parse(res)
              const netError = response.netError
              if (netError == 0) {
                try {
                  const responseMap =
                    typeof response.responseMap === 'object'
                      ? response.responseMap
                      : JSON.parse(response.responseMap)
                  const success = responseMap.success
                  const params = {
                    type: status,
                    channelId: channelId.value,
                    newsType: state.details.newsType,
                    newsId: state.details.newsId,
                    newsTitle: state.details.newsTitle,
                    sceneId: state.details.sceneId,
                    itemId: state.details.itemId,
                    subSceneId: state.details.subSceneId,
                    cnsTraceId: state.cnsTraceId,
                    isNewspaper: isNewspaper.value,
                    duration: dayjs().diff(statrTime.value, 'second')
                  }

                  if (status == 1) {
                    params.followPDUserId = state.details.rmhId
                    params.followUserName = state.details.rmhName
                  } else if (status == 0) {
                    params.cancelFollowPDUseId = state.details.rmhId
                    params.cancelFollowUserName = state.details.rmhName
                  }
                  if (success) {
                    // 关注成功
                    if (status == 1) {
                      try {
                        sendNative('jsCall_pointLevelOperate', {
                          operateType: '6'
                        }, () => {
                        })
                      } catch (e) {}
                      followTypePoint(params)
                      clookStatus() // 调关注状态查询，更新按钮上的文字
                      try {
                        sendNative('jsCall_currentPageOperate', {
                          operateType: '24',
                          creatorId: `${state.details.rmhId}`,
                          followStatus: '1'
                        }, () => {})
                      } catch (e) {}
                    } else if (status == 0) {
                      // 取消关注成功
                      followTypePoint(params)
                      clookStatus() // 调关注状态查询，更新按钮上的文字
                      try {
                        sendNative('jsCall_currentPageOperate', {
                          operateType: '24',
                          creatorId: `${state.details.rmhId}`,
                          followStatus: '0'
                        }, () => {})
                      } catch (e) {}
                    }
                  }
                } catch (e) { }
              } else {
                toast('网络出小差了，请检查网络后重试')
              }
            }
          )
        } catch (e) { }
      }
    }
    // 查询关注状态 initStatus(判断是不是第一次进入以及关注页面返回)
    const clookStatus = async (initStatus) => {
      if (window.config.VUE_BASE_NODE === 'dev') {
        const response = await axiosRequest({
          url: '/interact/zh/c/batchAttention/status',
          methot: 'post',
          appStatus: false,
          environment: state.environment,
          prefix: '/api/rmrb-interact',
          data: {
            creatorIds: [ { creatorId: `${state.details.rmhId}` } ]
          },
          headers: state.appHeader,
          showError: false
        })
        if (response.success) {
          clookStatusSee.value = response.data[0].status == '1' ? false : true //  '1' 是已关注  '0'是未关注
        }
      } else {
        if (state.creatorID == state.details.rmhId) {
          isOwer.value = true
          clookStatusSee.value = false
          nextTick(() => {
            if (document.querySelector('.skeleton-loading').classList.contains('active')) {
              changeContentHtmlHeight()
            }
          })
          return
        }

        try {
          sendNative(
            'jsCall_callAppService',
            {
              method: 'post',
              url: '/api/rmrb-interact/interact/zh/c/batchAttention/status',
              parameters: {
                //userId为用户id
                creatorIds: [ { creatorId: `${state.details.rmhId}` } ]
              }
            },
            res => {
              const statusResponse =
                typeof res === 'object' ? res : JSON.parse(res)
              const netError = statusResponse.netError
              const statusResponseMap =
                typeof statusResponse.responseMap === 'object'
                  ? statusResponse.responseMap
                  : JSON.parse(statusResponse.responseMap)
              if (netError == 0) {
                try {
                  const code = statusResponseMap.code
                  const data = statusResponseMap.data
                  if ([ 200, '0' ].includes(code)) {
                    if (data) {
                      if (data[0].status == '1') {
                        state.initClockStatus = !initStatus
                      } else {
                        state.initClockStatus = false
                      }
                      if (state.creatorID == state.details.rmhId) {
                        isOwer.value = true
                        clookStatusSee.value = false
                      } else {
                        clookStatusSee.value = data[0].status == '1' ? false : true //  '1' 是已关注  '0'是未关注
                      }
                      clookBtnActive.value = false
                      clookCancelBtnActive.value = false
                    } else {
                      clookStatusSee.value = true //  '1' 是已关注  '0'是未关注
                      state.initClockStatus = false
                      clookBtnActive.value = false
                      clookCancelBtnActive.value = false
                    }
                  }

                  nextTick(() => {
                    if (document.querySelector('.skeleton-loading').classList.contains('active')) {
                      changeContentHtmlHeight()
                    }
                  })
                } catch (e) { }
              } else {
                toast('网络出小差了，请检查网络后重试')
              }
            }
          )
        } catch (e) { }
      }
    }
    // 监听页面离开状态用于判断关注信息
    const queryPageLeaveStatus = () => {
      let objEvt = window.config.VUE_APP_LOGIN
        ? window.config.VUE_APP_LOGIN
        : ''
      let lastObjEvt =
        typeof objEvt === 'object' ? objEvt : JSON.parse(objEvt)
      if (lastObjEvt && lastObjEvt.event == '1') {
        // changeContentHtmlHeight({ report: true })
      }
      if (lastObjEvt && lastObjEvt.event == '1' && !loginTime.value && isPageLeave.value) {
        isPageLeave.value = false
        setTimeout(() => {
          clookStatus(true) // 调关注状态查询，更新按钮上的文字
        }, 200)
      }
    }

    /**
     * @Author      gx12358
     * @DateTime    2024/7/5
     * @lastTime    2024/7/5
     * @description 投票交互
     */
    const wheelFun = (vid, nid, type, index) => {
      // 轮训查询是否从登录页回到图文详情
      loginTime.value = setInterval(() => {
        try {
          let objEvt = window.config.VUE_APP_LOGIN
            ? window.config.VUE_APP_LOGIN
            : ''
          let lastObjEvt =
            typeof objEvt === 'object' ? objEvt : JSON.parse(objEvt)
          if (lastObjEvt && lastObjEvt.event == '1') {
            if (window.config.VUE_BASE_NODE === 'dev') {
              clearInterval(loginTime.value)
              loginTime.value = null

              if (type === 'vote') {
                state.isLogined = 1
                refreshVotes(nid, 0, () => {
                  voteStatus(vid, index, () => {
                    nextTick(() => {
                      if (document.querySelector('.skeleton-loading').classList.contains('active')) {
                        changeContentHtmlHeight()
                      }
                    })
                  })
                })
              } else if (type === 'follow') {
                clookStatus() // 调关注状态查询，更新按钮上的文字
              }
            } else {
              getUserLoginStatus(loginId => {
                clearInterval(loginTime.value)
                loginTime.value = null
                if (loginId == 1) {
                  // 由登录页面进到了主页面
                  if (type === 'vote') {
                    refreshVotes(nid, 0, () => {
                      voteStatus(vid, index, () => {
                        nextTick(() => {
                          if (document.querySelector('.skeleton-loading').classList.contains('active')) {
                            changeContentHtmlHeight()
                          }
                        })
                      })
                    })
                  } else if (type === 'follow') {
                    clookStatus() // 调关注状态查询，更新按钮上的文字
                  }
                } else {
                  clookBtnActive.value = false
                  clookCancelBtnActive.value = false
                }
              })
            }
          }
        } catch (e) { }
      }, 20)
    }
    // 开启轮训查询
    const checkAppLoginStatu = (type, index) => wheelFun(state.voteId, state.details.newsId, type, index)
    // 开始投票
    const goVote = (voteId, optionId, index) => {
      if (!state.details.endTimePoint) {
        if (window.config.VUE_BASE_NODE === 'dev') {
        }
        toast('投票已过期')
        return
      }

      window.config.VUE_APP_LOGIN = '' // 由于页面加载就会给 '1' ,所以点投票先清空，否则会影响后面的轮巡判断

      if (window.config.VUE_BASE_NODE === 'dev') {
        const optionInfo = optionList.value.find(item => item.optionId == optionId)
        normalClickTypePoint({
          channelId: channelId.value,
          newsType: state.details.newsType,
          newsId: state.details.newsId,
          newsTitle: state.details.newsTitle,
          sceneId: state.details.sceneId,
          itemId: state.details.itemId,
          subSceneId: state.details.subSceneId,
          voteOption: `${optionId}`,
          voteContent: optionInfo ? optionInfo.summary : '',
          cnsTraceId: state.cnsTraceId,
          isNewspaper: isNewspaper.value,
          duration: dayjs().diff(statrTime.value, 'second')
        })

        // 模拟去登录
        state.voteId = voteId
        setTimeout(() => {
          const event = {
            event: '1'
          }
          window.config.VUE_APP_LOGIN = JSON.stringify(event)
        }, 100)
        checkAppLoginStatu('vote', index)
      } else {
        if (state.isLogined == 1) {
          // 已登录 直接去投票
          if (state.Doing) {
            return
          } else {
            try {
              sendNative('jsCall_currentPageOperate', {
                operateType: '47'
              }, () => {})
            } catch (e) {}
            state.Doing = true
            setVote(voteId, optionId, index)
          }
        } else {
          state.voteId = voteId
          setAppLogin()
          checkAppLoginStatu('vote')
        }
      }
    }
    // 用户投票
    const setVote = async (vID, oID, index) => {
      if (window.config.VUE_BASE_NODE === 'dev') {} else {
        try {
          sendNative(
            'jsCall_callAppService',
            {
              method: 'post',
              url: '/api/rmrb-contact/contact/zh/c/vote/submit',
              parameters: { voteId: `${vID}`, optionId: oID }
            },
            res => {
              const vtSubmitResponse =
                typeof res === 'object' ? res : JSON.parse(res)
              const netError = vtSubmitResponse && vtSubmitResponse.netError
              const vtSubmitResponseMap =
                typeof vtSubmitResponse.responseMap === 'object'
                  ? vtSubmitResponse.responseMap
                  : JSON.parse(vtSubmitResponse.responseMap)
              if (netError == 0) {
                try {
                  const code = vtSubmitResponseMap.code
                  const newId = state.details.newsId
                  if ([ 200, '0' ].includes(code)) {
                    const optionInfo = optionList.value.find(item => item.optionId == oID)
                    try {
                      normalClickTypePoint({
                        channelId: channelId.value,
                        newsType: state.details.newsType,
                        newsId: state.details.newsId,
                        newsTitle: state.details.newsTitle,
                        sceneId: state.details.sceneId,
                        itemId: state.details.itemId,
                        subSceneId: state.details.subSceneId,
                        voteOption: `${oID}`,
                        voteContent: optionInfo ? optionInfo.summary : '',
                        cnsTraceId: state.cnsTraceId,
                        isNewspaper: isNewspaper.value,
                        duration: dayjs().diff(statrTime.value, 'second')
                      })
                    } catch (e) {

                    }
                    try {
                      sendNative('jsCall_currentPageOperate', {
                        operateType: '48'
                      }, () => {
                      })
                    } catch (e) {}
                    toast('投票成功')
                    // 刷新投票状态
                    refreshVotes(newId, 0, () => {
                      voteStatus(vID, index, () => {
                        nextTick(() => {
                          if (document.querySelector('.skeleton-loading').classList.contains('active')) {
                            changeContentHtmlHeight()
                          }
                        })
                      }) // 投票前  投票后
                    })

                    state.Doing = false
                  } else {
                    toast(vtSubmitResponseMap.message)
                  }
                } catch (e) { }
              } else {
                toast('网络出小差了，请检查网络后重试')
              }
            }
          )
        } catch (e) { }
      }
    }
    // 刷新投票状态
    const refreshVotes = async (eq, id, callback) => {
      if (window.config.VUE_BASE_NODE === 'dev') {
        setTimeout(() => {
          const refResponse = {
            netError: 0,
            responseMap: {
              code: '0',
              data: [
                {
                  voteInfo: shallowMergeObj(state.originDataSource.voteInfo, {
                    options: [
                      {
                        backColor: '#486FFF',
                        index: 1,
                        optionId: 8537,
                        summary: 2,
                        totalVotes: 1,
                        wordColor: '#FFFFFF'
                      },
                      {
                        backColor: '#486FFF',
                        index: 2,
                        optionId: 8538,
                        summary: 1,
                        totalVotes: 0,
                        wordColor: '#FFFFFF'
                      }
                    ]
                  })
                }
              ]
            }
          }
          const refResponseMap =
            typeof refResponse.responseMap === 'object'
              ? refResponse.responseMap
              : JSON.parse(refResponse.responseMap)
          if (refResponseMap.data && refResponseMap.code) {
            const code = refResponseMap.code
            const data = refResponseMap.data[0]
            if ([ 200, '0' ].includes(code) && data) {
              if (Object.keys(data).length > 0) {
                handleVoteData(data)
                if (callback) callback()
              }
            } else {
              toast('网络出小差了，请检查网络后重试')
            }
          } else {
            toast('网络出小差了，请检查网络后重试')
          }
        }, 100)
      } else {
        try {
          const reLInfo = state.details.reLInfo ? {
            relType: state.details.reLInfo.relType,
            relId: state.details.reLInfo.relId
          } : {}
          sendNative(
            'jsCall_callAppService',
            {
              method: 'post',
              url: '/api/rmrb-bff-display-zh/content/zh/c/content/detail',
              parameters: {
                contents: shallowMergeObj({
                  contentId: eq
                }, reLInfo)
              }
            },
            (res) => {
              logInfo('res', res)
              try {
                const refResponse =
                  typeof res === 'object' ? res : JSON.parse(res)
                const netError = refResponse.netError
                if (netError == 0) {
                  const refResponseMap =
                    typeof refResponse.responseMap === 'object'
                      ? refResponse.responseMap
                      : JSON.parse(refResponse.responseMap)
                  if (refResponseMap.data && refResponseMap.code) {
                    const code = refResponseMap.code
                    const data = refResponseMap.data[0]
                    if ([ 200, '0' ].includes(code) && data) {
                      if (Object.keys(data).length > 0) {
                        handleVoteData(data)

                        if (callback) callback()
                      }
                    } else {
                      toast('网络出小差了，请检查网络后重试')
                    }
                  } else {
                    toast('网络出小差了，请检查网络后重试')
                  }
                } else {
                  toast('网络出小差了，请检查网络后重试')
                }
              } catch (e) {
                logInfo('error', e)
              }
            }
          )
        } catch (e) { }
      }
    }
    // 用户投票状态查询
    const voteStatus = async (vId, index, callBack) => {
      if (window.config.VUE_BASE_NODE === 'dev') {
        voteInit.value = true
        state.voteState.status = 1      //  决定是投票前0 还是 投票后1
        nextTick(() => handleVoteList())
        if (state.details.voteInfo.style === 1) {
          //  展示对 √
          if (index) {
            state.bcIndex = index
          }
        } else {
          if (index) {
            state.curIndex = index
          }
        }
        if (callBack) callBack()
      } else {
        try {
          sendNative(
            'jsCall_callAppService',
            {
              method: 'get',
              url: '/api/rmrb-contact/contact/zh/c/vote/queryStatus',
              parameters: { voteId: vId }
            },
            res => {
              const voteStatusResponse =
                typeof res === 'object' ? res : JSON.parse(res)
              const netError = voteStatusResponse.netError
              const vtStatusResponseMap =
                typeof voteStatusResponse.responseMap === 'object'
                  ? voteStatusResponse.responseMap
                  : JSON.parse(voteStatusResponse.responseMap)
              if (netError == 0) {
                try {
                  const code = vtStatusResponseMap.code
                  const data = vtStatusResponseMap.data
                  if ([ 200, '0' ].includes(code) && data) {
                    if (Object.keys(data).length > 0) {
                      try {
                        state.voteState.status = data.status      //  决定是投票前0 还是 投票后1
                        state.voteState.optionId = data.optionId      // 返回的是 被投票项的 optionId ，没投就是 ''
                        nextTick(() => handleVoteList())
                      } catch (e) {}
                      if (state.details.voteInfo.style === 1) {
                        //  展示对 √
                        if (index) {
                          state.bcIndex = index
                        }
                      } else {
                        if (index) {
                          state.curIndex = index
                        }
                      }

                      if (callBack) callBack()
                    }
                  } else {
                    toast(vtStatusResponseMap.message)
                  }
                } catch (e) { }
              } else {
                toast('网络出小差了，请检查网络后重试')
              }
            }
          )
        } catch (e) { }
      }
    }
    // 处理投票List给页面使用
    const handleVoteList = () => {
      const tots = voteOtions.value.length
        ? voteOtions.value.reduce((x, i) => x + i.totalVotes, 0)
        : 0

      let datsArr = voteOtions.value.length
        ? voteOtions.value.map(ep => {
          ep.votesBf = tots > 0 ? parseInt(ep.totalVotes / tots * 100) : 0
          return ep
        })
        : []
      if (tots != 0) {  // 这里面的作用，让投票结果百分数之和恰好为 100%
        let bfTols = 0
        let bfMax = datsArr[0].votesBf
        let index = 0
        let bfgDiff = 0
        for (let i = 0; i < datsArr.length; i++) {
          bfTols += datsArr[i].votesBf
          if (bfMax < datsArr[i].votesBf) {
            bfMax = datsArr[i].votesBf
            index = i
          }
        }
        bfgDiff = bfTols - 100
        if (bfgDiff > 0) {
          datsArr[index].votesBf = bfMax - bfgDiff
        } else if (bfgDiff < 0) {
          datsArr[index].votesBf = bfMax + Math.abs(bfgDiff)
        } else {}
      } else {
        if (datsArr.length > 0 && state.details.voteInfo && state.details.voteInfo.style === 1) {
          if (datsArr[0].votesBf === 0 && datsArr[1].votesBf === 0) {
            datsArr = datsArr.map(item => {
              return shallowMergeObj(item, {
                votesBf: 50
              })
            })
          }
        }
      }

      datsArr = deepCopy(datsArr).map((item, index) => {
        oneWidth = state.details.voteInfo.style == 1 && index === 0
          ? datsArr[index + 1].votesBf == 0 && item.votesBf == 0
            ? 50
            : (item.votesBf == 0 ? 8 : datsArr[index + 1].votesBf == 0 ? 92 : item.votesBf)
          : 0
        twoWidth = state.details.voteInfo.style == 1 && index === 1
          ? datsArr[index - 1].votesBf == 0 && item.votesBf == 0
            ? 50
            : (item.votesBf == 0 ? 8 : datsArr[index - 1].votesBf == 0 ? 92 : item.votesBf)
          : 0
        if ((state.isLogined != 1 || state.voteState.status === 0)) {
          oneWidth = 50
          twoWidth = 50
        }
        const voteAnimate = document.getElementById('voteAnimate')

        if (oneWidth && index === 0 && state.details.voteInfo.style == 1) {
          const oneCssStr = `@keyframes voteProgressIn {
            0% {
              width: calc(50% - 0.5px);
            }
            
            100% {
              width: calc(${oneWidth}% - 0.5px);
            }
          }`
          jqHtml(voteAnimate, { type: 'set', str: jqHtml(voteAnimate, { type: 'get' }) + oneCssStr })
        }

        if (twoWidth && index === 1 && state.details.voteInfo.style == 1) {
          const twoCssStr = `@keyframes voteProgressInTwo {
            0% {
               width: calc(50% - 0.5px);
            }
            
            100% {
              width: calc(${twoWidth}% - 0.5px);
            }
          }`
          jqHtml(voteAnimate, { type: 'set', str: jqHtml(voteAnimate, { type: 'get' }) + twoCssStr })
        }

        const oneStyle = {
          width: `calc(${oneWidth}%)`,
          clipPath: `polygon(0 0, 100% 0, calc(100% - 12px) 100%, 0 100%)`,
          '-webkit-clip-path': `polygon(0 0, 100% 0, calc(100% - 12px) 100%, 0 100%)`,
          color: item.wordColor || undefined,
          background: item.backColor || undefined
        }
        const twoStyle = {
          width: `calc(${twoWidth}%)`,
          clipPath: `polygon(12px 0, 100% 0, 100% 100%, 0 100%)`,
          '-webkit-clip-path': `polygon(12px 0, 100% 0, 100% 100%, 0 100%)`,
          color: item.wordColor || undefined,
          background: item.backColor || undefined
        }
        return shallowMergeObj(item, {
          oneStyle: shallowMergeObj(oneStyle, {
            width: `50%`
          }),
          oneStyleFront: shallowMergeObj(oneStyle, {
            width: 'calc(50% + 2.5px)'
          }),
          oneStyleAfter: {
            width: `calc(50%)`,
            background: item.backColor,
            clipPath: `polygon(0 0, 100% 0, calc(100% - 4px) 100%, 0 100%)`,
            '-webkit-clip-path': `polygon(0 0, 100% 0, calc(100% - 4px) 100%, 0 100%)`
          },
          twoStyle: shallowMergeObj(twoStyle, {
            width: `50%`
          }),
          twoStyleFront: shallowMergeObj(twoStyle, {
            width: 'calc(50% + 2.5px)'
          }),
          twoStyleAfter: {
            width: `calc(50%)`,
            background: item.backColor,
            clipPath: `polygon(4px 0, 100% 0, 100% 100%, 0 100%)`,
            '-webkit-clip-path': `polygon(4px 0, 100% 0, 100% 100%, 0 100%)`
          }
        })
      })

      optionList.value = deepCopy(datsArr)
    }
    // 将投票相关信息处理成多个本地变量
    const handleVoteData = (data) => {
      state.details.voteInfo = data.voteInfo
      // 投票信息结束时间为空endTimePoint则为false，否则结束时间大于当前时间endTimePoint则为data.voteInfo.endTime，否则endTimePoint为Close
      state.details.endTimePoint = data.voteInfo.endTime === '' || !data.voteInfo.endTime
        ? true
        : (data.voteInfo.endTime - Date.now()) > 0
          ? true
          : false
      voteOtions.value = data.voteInfo.options ? Array.isArray(data.voteInfo.options)
        ? data.voteInfo.options
        : [] : []
      //投票信息选项存在且投票信息选项标题存在，则把投票信息选项标题赋值给yes
      state.details.yes = data.voteInfo.options && data.voteInfo.options[0]
      //投票信息选项存在且投票信息选项排序存在，则把投票信息选项排序赋值给no
      state.details.no = data.voteInfo.options && data.voteInfo.options[1]
    }

    /**
     * @Author      gx12358
     * @DateTime    2024/7/5
     * @lastTime    2024/7/5
     * @description 动态监听App传参
     */
    const pageReloadChange = () => {
      // 监听App复用模版
      if (window.config.VUE_BASE_NODE === 'dev') {
        if (pageLoadOutTime || hasDetails) {
          return
        }

        firstTime = new Date()
        pageLoadOutTime = null
        hasDetails = false
        checkPageLoadingTimeOut()
      } else {
        try {
          const objEvt = window.config.PAGERELOAD ? window.config.PAGERELOAD : ''
          const pageReloadInfo = typeof objEvt === 'object' ? objEvt : JSON.parse(objEvt)
          if (pageReloadInfo && pageReloadInfo.event == '7') {  // 复用重新进入
            if (pageLoadOutTime || hasDetails) {
              return
            }

            document.querySelector('.error-block').style.display = 'none'
            darkMode = pageReloadInfo.darkMode || darkMode
            state.darkMode = darkMode
            document
            .querySelector('html')
            .setAttribute('dark-mode', darkMode === 'dark')
            firstTime = new Date()
            pageLoadOutTime = null
            hasDetails = false
            checkPageLoadingTimeOut()
          }
        } catch (e) {

        }
      }
    }
    // 监听改变软件字体大小
    const changeAppFontSize = () => {
      if (window.config.VUE_BASE_NODE === 'dev') {
        const fontSizes = 'Large'
        state.appFontSize = fontSizes
        appFontSize = state.appFontSize
        setRemUnit(state.appFontSize)
      } else {
        try {
          const objEvt = window.config.APP_FONT_SIZE ? window.config.APP_FONT_SIZE : ''
          const appFontSizeEvent = objEvt ? typeof objEvt === 'object' ? objEvt : JSON.parse(objEvt) : undefined
          if (appFontSizeEvent && appFontSizeEvent.event == '10') {
            const fontSizes = appFontSizeEvent.fontSizes
            state.appFontSize = fontSizes
            appFontSize = state.appFontSize
            setRemUnit(state.appFontSize)
            // setTimeout(() => {
            //   if (currentVideo.el && currentVideo.videoUrl) {
            //     const player = currentVideo.el
            //     const width = player.parentNode.getBoundingClientRect().width
            //     const height = player.parentNode.getBoundingClientRect().height
            //     const top = player.parentNode.offsetTop
            //     const left = player.parentNode.getBoundingClientRect().left
            //     const videoLandscape = width > height ? '1' : (width < height ? '2' : '')
            //
            //     // logInfo('视频播放', width, height, left, top)
            //
            //     if (window.config.VUE_BASE_NODE === 'dev') {
            //       console.log('视频播放', width, height, left, top)
            //     }
            //
            //     try {
            //       sendNative(
            //         'jsCall_currentPageOperate',
            //         {
            //           operateType: '49',
            //           positionLeft: `${left}`,
            //           positionTop: `${top}`,
            //           positionWidth: `${width}`,
            //           positionHeight: `${height}`,
            //           videoLandscape: `${videoLandscape}`,
            //           videoUrl: `${currentVideo.videoUrl}`
            //         },
            //         res => {
            //         }
            //       )
            //     } catch (e) {}
            //   }
            // }, 0)
          }
        } catch (e) {

        }
      }
    }
    // 监听改变软件皮肤模式
    const changeDarkMode = () => {
      try {
        const objEvt = window.config.DARK_MODE ? window.config.DARK_MODE : ''
        const appDarkMode = objEvt ? typeof objEvt === 'object' ? objEvt : JSON.parse(objEvt) : undefined
        if (appDarkMode && appDarkMode.event == '9') {
          darkMode = appDarkMode.darkMode || darkMode
          state.darkMode = darkMode
          document
          .querySelector('html')
          .setAttribute('dark-mode', darkMode == 'dark')
        }
      } catch (e) {

      }
    }
    const changeState = () => {
      const stateObj = window.config.VUE_STATE
      if (stateObj) {
        const key = stateObj.key
        const value = stateObj.value
        state[key] = value
      }
    }
    // 监听网络状态
    const changeNetworkStatus = () => {
      if (window.config.VUE_BASE_NODE === 'dev') {
        networkStatus.value = window.config.VUE_APP_NETWORK
      } else {
        const objNvt = window.config.VUE_APP_NETWORK ? window.config.VUE_APP_NETWORK : {}
        const lastObjNvtNetwork = typeof objNvt === 'object' ? objNvt : JSON.parse(objNvt)
        networkStatus.value = lastObjNvtNetwork.networkStatus
      }
    }
    // 监听媒体播放状态
    const changeMediaPlayStatus = () => {
      if (window.config.VUE_BASE_NODE === 'dev') {
      } else {
        try {
          const objEvt = window.config.MEDIAPLAY ? window.config.MEDIAPLAY : ''
          const mediaPlayInfo = typeof objEvt === 'object' ? objEvt : JSON.parse(objEvt)
          if (mediaPlayInfo && mediaPlayInfo.event == '5') {  // 音频播放
            audioState.value += 1
          }
        } catch (e) { }
      }
    }
    // 退出图文详情页关闭音频播放
    const quitGraphicDetailPageEvent = () => {
      if (window.config.VUE_BASE_NODE === 'dev') {
      } else {
        try {
          const objQvt = window.config.VUE_APP_LOGIN ? window.config.VUE_APP_LOGIN : ''
          const lastObjQvt = typeof objQvt === 'object' ? objQvt : JSON.parse(objQvt)
          if (lastObjQvt && (lastObjQvt.event == '2' || lastObjQvt.event == '4')) {

            const _editor36 = document.querySelectorAll('.preview-audio-player')
            const coverAudioList = document.querySelectorAll('.preview-audio-player-cover')
            if (_editor36) {
              _editor36.forEach((item, _) => {
                const audioStylePlay = item.querySelector('.audio-play-icon')
                const audioStylePause = item.querySelector('.audio-pause-icon')

                const item_audio = item.querySelector('[class^="audio-block"]')
                if (item_audio) {
                  item_audio.pause()
                  audioStylePause.style.display = 'none'
                  audioStylePlay.style.display = 'block'
                }
              })
            }

            if (coverAudioList) {
              coverAudioList.forEach((item, _) => {
                const audioStylePlay = item.querySelector('.audio-play-icon')
                const audioStylePause = item.querySelector('.audio-pause-icon')

                const item_audio = item.querySelector('[class^="audio-block"]')
                if (item_audio) {
                  item_audio.pause()
                  audioStylePause.style.display = 'none'
                  audioStylePlay.style.display = 'block'
                }
              })
            }

          }
        } catch (e) { }
      }
    }

    /**
     * @Author      gx12358
     * @DateTime    2024/7/5
     * @lastTime    2024/7/5
     * @description 与App交互方法
     */
    const setAppLogin = () => {
      // 未登录时执行，拉起app登录
      try {
        sendNative(
          'jsCall_appInnerLinkMethod',
          {
            appInnerLink:
              'rmrbapp://rmrb.app/openwith?type=app&subType=login&skipType=2'
          },
          res => { }
        )
      } catch (e) { }
    }
    // 获取用户登录状态
    const getUserLoginStatus = (callback) => {
      try {
        sendNative('jsCall_getAppLoginAuthInfo', {}, res => {
          const loginStatusResponse =
            typeof res === 'object' ? res : JSON.parse(res)
          state.isLogined =
            loginStatusResponse && loginStatusResponse.isLogined

          if (callback !== undefined) {
            callback(state.isLogined)
          }
        })
      } catch (e) { }
    }
    const sendParams = callback => {
      sendNative(
        'jsCall_receiveH5Data',
        { dataSource: '1', dataJson: JSON.stringify(state.originDataSource) },
        callback
      )
    }
    // 推荐每项的点击事件
    const recommondItemClick = index => {
      sendNative('jsCall_receiveH5Data', {
        dataSource: '2',
        dataJson: JSON.stringify(state.recomList[index])
      })
    }
    // 页面离开的时候初始化
    const clearData = () => {
      clearTimeout(pageLoadOutTime)
      document.querySelector('.error-block').style.display = 'none'
      jqHtml('#newsContent', { type: 'set', str: '' })
      loadingBlock(true)
      document.querySelector('.skeleton-loading').classList.add('active')
      appBlock(false)

      time.value = ''
      deviceType.value = judgTerminal() === 1 ? 'ad' : 'ios'
      statrTime.value = dayjs()
      loginTime.value = null
      channelId.value = null
      recordTime.value = dayjs()
      canSeeBtnTwo.value = true
      canSeeBtnOne.value = true
      isOwer.value = false
      hasReadCount.value = true
      isRmh.value = null
      isNewspaper.value = false
      voteInit.value = false
      showClook.value = false
      optionList.value = []
      subjectList.value = []
      channelList.value = []
      suggestedList.value = []
      voteOtions.value = []
      networkStatus.value = 4
      networkSwitch.value = 2
      audioState.value = 0
      browseCnt.value = '0'
      browseStr.value = ''
      loadlmageOnlyWifiSwitch.value = window.config.VUE_BASE_NODE === 'dev' ? '2' : '0'
      clookStatusSee.value = false
      clookCancelBtnActive.value = false
      clookBtnActive.value = false
      hasHeadLink.value = false
      isPageLeave.value = false
      hasInit.value = false
      shareOpen.value = false
      hasAppLoginExtra = false
      Object.assign(state, {
        clientHeight: 0,
        appFontSize: state.appFontSize,
        //投票id
        voteId: null,
        contentId: null,
        sourcePage: '2',
        //模式
        //环境
        environment: 'sit',
        showShare: false,
        //请求头
        appHeader: shallowMerge({
          system: judgTerminal() === 1 ? 'Android' : 'ios'
        }, window.config.VUE_BASE_HEADER),
        initialRes: {},
        originDataSource: {},
        //此details对接口返回的数据进行了二次改造，属性的添加和属性值的转换
        details: {
          rmhInfo: null,
          author: [],
          newLinkObject: {},
          //投票信息
          voteInfo: {},
          endTimePoint: false,
          yes: {},
          no: {},
          slideShows: {},
          //片头跳转
          headLinkdata: ''
        },
        initClockStatus: false,
        shareNewPoster: false,
        voteState: {
          status: 0,
          optionId: 0
        },
        creatorID: null,
        curIndex: 0,
        bcIndex: 0,
        Doing: false,
        isLogined: 0, // 0 未登录  1 已登录
        isSub: false,
        isSubClose: false,
        seeEmailSub: false,
        strategy: {},
        emailVal: '',
        deviceId: '',
        userId: '',
        aboutUserName: '',
        agreementURL: '',
        recomList: []
      })
      Object.assign(timeLine, {
        title: '',
        topicId: '',
        topicType: '',
        pageId: '',
        linkUrl: '',
        slideColor: '#ED2800',
        data: []
      })
      Object.assign(actieInfo, {
        show: false,
        id: -1,
        title: '',
        type: '',
        linkUrl: '',
        coverUrl: ''
      })

      refreshEditorStr()
      hasDetails = false
      pageLoadOutTime = null
      changeContentHtmlHeight()
      startShowArticle = false
    }
    // 模拟App页面离开的时候初始化
    const mockAppClearData = () => {
      clearData()

      setTimeout(() => {
        mockAppRequestDetails()
      })
    }

    return Object.assign({
      isRmh,
      isNewspaper,
      isOwer,
      deviceType,
      browseCnt,
      browseStr,
      baseNode,
      actieInfo,
      voteInit,
      hasHeadLink,
      canSeeBtnOne,
      canSeeBtnTwo,
      subjectList,
      channelList,
      suggestedList,
      voteOtions,
      optionList,
      showClook,
      clookStatusSee,
      timeLine,
      shareOpen,
      hasReadCount,
      clookBtnActive,
      clookCancelBtnActive,
      pageReloadChange,
      requestApp,
      clearData,
      mockAppClearData,
      inptClick,
      removeHtmlStr,
      moreInformationClick,
      recommondItemClick,
      clookBtn,
      clookCancelBtn,
      skipCustomerNumberPage,
      goVote,
      openShare,
      sendParams,
      changeNetworkStatus,
      changeMediaPlayStatus,
      openMoreTimeLine,
      queryPageLeaveStatus,
      quitGraphicDetailPageEvent,
      openActiveLink,
      reload,
      changeAppFontSize,
      changeDarkMode,
      changeState,
      changeAppError
    }, toRefs(state))
  }
})

app.mount('#app')

app.config.errorHandler = (err) => {
  h5ErrorPage(err.toString())
}
