class DragFixInt {
  constructor(player, event) {
    this.player = player
    this.event = event

    this.target = this.player.container

    this.dataState = {
      dragIng: false,
      position: { x: 0, y: 0 },
      pressedDelta: {}
    }

    this.start = this.start.bind(this)
    this.move = this.move.bind(this)
    this.end = this.end.bind(this)
  }

  start(e) {
    const event = e.touches[0] || e.changedTouches[0]
    this.dataState.dragIng = true
    const rect = this.target.getBoundingClientRect()
    const pos = {
      x: event.clientX - rect.left,
      y: event.clientY - rect.top
    }
    this.dataState.pressedDelta = pos
  }

  move(e) {
    e.preventDefault()
    const event = e.touches[0] || e.changedTouches[0]
    if (!this.dataState.pressedDelta)
      return
    this.dataState.position = {
      x: event.clientX - this.dataState.pressedDelta.x,
      y: event.clientY - this.dataState.pressedDelta.y
    }

    let padding = getComputedStyle(document.querySelector('.gx-mobile')).paddingLeft

    if (padding) {
      padding = padding.split('px')[0]

      padding = Number(padding).toFixed(3)

      padding = Number(padding)
    }

    const right = getTextWidth('', {
      width: `${0.6 / 37.5}rem`,
      display: 'block'
    })

    let top = getTextWidth('', {
      width: `${0.2 / 37.5}rem`,
      display: 'block'
    })

    top = -top

    const maxX = window.innerWidth - this.target.getBoundingClientRect().width - padding + right
    const maxY = window.innerHeight - this.target.getBoundingClientRect().height -
      (document.querySelector('.footer').getBoundingClientRect().height || 0)

    if (this.dataState.position.y < top) this.dataState.position.y = top
    if (this.dataState.position.y > maxY) this.dataState.position.y = maxY
    if (this.dataState.position.x < padding) this.dataState.position.x = padding
    if (this.dataState.position.x > maxX) this.dataState.position.x = maxX

    this.target.style.left = `${this.dataState.position.x}px`
    this.target.style.top = `${this.dataState.position.y}px`
  }

  end() {
    if (!this.dataState.pressedDelta)
      return
    this.dataState.pressedDelta = undefined
    this.dataState.dragIng = false
  }

  handleDrag() {
    if (!this.target) return
    this.target.addEventListener('touchstart', this.start)
    this.target.addEventListener('touchmove', this.move)
    this.target.addEventListener('touchend', this.end)
  }

  removeDrag() {
    if (!this.target || !this.target) return
    this.target.removeEventListener('touchstart', this.start)
    this.target.removeEventListener('touchmove', this.move)
    this.target.removeEventListener('touchend', this.end)
  }
}
