class Events {
  constructor(player) {
    this.player = player
    this.bottomStateTime = 3000
    this.initVideo = false
    this.dragFixed = false
    this.playerEnd = false
    this.isDragging = false
    this.clearBottomTime = null
    this.destroyEvents = []
    this.proxy = this.proxy.bind(this)

    this.layerDom = new LayerDom(player, this)
    this.touchInt = new TouchInt(player, this)
    this.dragFixInt = new DragFixInt(player, this)

    this.addOtherEvent()
    clickPoster(player, this)
    clickContainer(player, this)
    clickNetworkBlock(player, this)
    clickNetworkBlockBtn(player, this)
    clickLayerStateBlock(player, this)
    clickLayerStateBtn(player, this)
    clickBottomState(player, this)
    clickBottonFullScreen(player, this)
    clickReplayBlock(player, this)
    clickReplayBtn(player, this)
    clickMiniLayerBlcok(player, this)
    clickMiniLayerBtn(player, this)
    clickMiniCloseBtn(player, this)
  }

  clearSetTimeOut() {
    if (this.clearBottomTime) {
      clearTimeout(this.clearBottomTime)
      this.clearBottomTime = null
    }
  }

  initPlayer() {
    if (this.initVideo) {
      return
    }

    this.initVideo = true
    if (window.config.VUE_BASE_NODE !== 'dev') {
      // this.player.template.$cover.style.backgroundSize = this.player.options.record.poster ? 'contain' : `3.52rem 1.6rem`
    }
    this.layerDom.toggleCommonLayer(this.player.template.$loading, false)

    $(this.player.template.$bottomDuration).html(`${formatDuraton(this.player.player.getDuration())}`)

    if (hasClass(this.player.template.$container.parentNode, 'init')) {
      this.player.template.$cover.querySelector('.player-state-icon').style.display = 'none'
      this.layerDom.toggleLayerPause(true)

      this.player.player.pause()

      setTimeout(() => {
        this.layerDom.toggleCommonLayer(this.player.template.$loading, false)
        this.player.player.pause()
      }, 50)
    } else {
      this.clearSetTimeOut()
      this.layerDom.toggleBottomPlayState(true)
      this.player.template.$cover.querySelector('.player-state-icon').style.display = 'block'
      this.layerDom.toggleCommonLayer(this.player.template.$layerState, false)
    }
  }

  initEventPlayer(posterError = true) {
    this.initPlayer()
    removeClass(this.player.template.$container.parentNode, 'init')
    if (!this.player.originPoster || !posterError) {
      this.layerDom.toggleCommonLayer(this.player.template.$cover, false)
    }
  }

  async addOtherEvent() {
    try {
      const _that = this
      if (this.player.options.isGiveWidth && this.player.previewPoster) {
        this.player.player.pause()
      } else {
        this.player.player.on('ready', () => {
          setTimeout(() => {
            this.player.player.pause()
          })
          if (!this.player.options.isGiveWidth) {
            const video = this.player.player ? this.player.player.tag : null
            const videoWidth = video.videoWidth || 0
            const videoHeight = video.videoHeight || 0
            this.player.callBackFun.ready(videoWidth, videoHeight, (height) => {
              this.player.options.videoOptions.height = height
              this.player.options.videoOptions.originWidth = videoWidth
              this.player.options.videoOptions.originHeight = videoHeight
            })

            this.initEventPlayer()
          }
        })
      }


      const imageEl = this.player.container.querySelector('.player-cover > img')
      imageEl.src = this.player.previewPoster

      imageEl.onload = function () {
        imageEl.style.display = 'block'
        _that.player.container.querySelector('.player-cover').style.backgroundImage = ''
        _that.player.container.querySelector('.player-cover').style.backgroundSize = 'cover'

        if (_that.player.options.isGiveWidth) {
          _that.initEventPlayer()
        }
      }

      imageEl.onerror = function () {
        _that.player.container.querySelector('video').setAttribute('poster', '')
        _that.initEventPlayer(false)
      }
    } catch (e) {
    }
  }

  proxy(target, name, callback, option = {}) {
    if (Array.isArray(name)) {
      return name.map((item) => this.proxy(target, item, callback, option))
    }

    target.addEventListener(name, callback, option)
    const destroy = () => target.removeEventListener(name, callback, option)
    this.destroyEvents.push(destroy)
    return destroy
  }

  remove(destroyEvent) {
    const index = this.destroyEvents.indexOf(destroyEvent)
    if (index > -1) {
      destroyEvent()
      this.destroyEvents.splice(index, 1)
    }
  }

  destroy() {
    for (let index = 0; index < this.destroyEvents.length; index++) {
      this.destroyEvents[index]()
    }
  }
}
