class TouchInt {
  constructor(player, event) {
    this.touchState = {
      start: 0
    }
    this.progressType = 'click'

    this.addEvent(event, player)
  }

  addEvent(event, player) {
    event.proxy(player.template.$bottomProgressBlock, 'touchstart', (e) => {
      if (player.player.getStatus() === 'loading') {
        return
      }

      const width = player.template.$bottomLoaded.style.width
      this.touchState.start = width
      event.layerDom.tooglePlayerBottom(true)
      event.clearSetTimeOut()
    })

    event.proxy(player.template.$bottomProgressBlock, 'touchmove', (e) => {
      event.clearSetTimeOut()

      event.isDragging = true

      if (event.isDragging) {
        const touch = e.touches[0]
        const playerProgressRect = player.template.$bottomProgress.getBoundingClientRect()
        const progressWidth = playerProgressRect.width
        const touchX = touch.clientX - playerProgressRect.left

        if (Math.abs(touchX) > 5) {
          this.progressType = 'move'

          // 计算移动的百分比
          let percentage = (touchX / progressWidth) * 100

          percentage = percentage > 100 ? 100 : percentage < 0 ? 0 : percentage

          const currentTime = (percentage / 100) * player.player.getDuration()

          player.template.$video.currentTime = currentTime > player.player.getDuration()
            ? player.player.getDuration() : currentTime < 0 ? 0 : currentTime

          // 设置 player-loaded 的宽度为百分比值
          jqHtml(player.template.$bottomCurrent, { type: 'set', str: `${formatDuraton(currentTime)}` })
          player.template.$bottomLoaded.style.width = `${percentage}%`
          player.template.$miniProgressLoaded.style.width = `${percentage}%`
        } else {
          this.progressType = 'click'
        }
      }
    })

    event.proxy(player.template.$bottomProgressBlock, 'touchend', (e) => {
      event.clearSetTimeOut()

      if (this.progressType === 'move') {
        event.isDragging = false

        if (player.template.$container) {
          let width = player.template.$bottomLoaded.style.width

          if (width) {
            width = width.split('%')[0]

            if (width) {
              width = Number(width)

              width = width / 100
              const currentTime = width * player.player.getDuration()

              player.template.$video.currentTime = currentTime > player.player.getDuration()
                ? player.player.getDuration() : currentTime < 0 ? 0 : currentTime
              jqHtml(player.template.$bottomCurrent, { type: 'set', str: `${formatDuraton(currentTime)}` })
              player.template.$bottomLoaded.style.width = `${width * 100}%`
              player.template.$miniProgressLoaded.style.width = `${width * 100}%`

              event.layerDom.tooglePlayerBottom(false, 3000)
              this.progressType = 'click'
            }
          }
        }
      } else {
        const playerProgressRect = player.template.$bottomProgress.getBoundingClientRect()
        const touch = e.changedTouches[0]
        const touchX = touch.clientX - playerProgressRect.left

        // 计算移动的百分比
        let percentage = (touchX / playerProgressRect.width) * 100

        percentage = percentage > 100 ? 100 : percentage < 0 ? 0 : percentage

        const width = percentage / 100
        const currentTime = width * player.player.getDuration()

        player.template.$video.currentTime = currentTime > player.player.getDuration()
          ? player.player.getDuration() : currentTime < 0 ? 0 : currentTime

        event.layerDom.tooglePlayerBottom(false, 3000)
        jqHtml(player.template.$bottomCurrent, { type: 'set', str: `${formatDuraton(currentTime)}` })
        player.template.$bottomLoaded.style.width = `${percentage}%`
        player.template.$miniProgressLoaded.style.width = `${percentage}%`
        this.progressType = 'click'
      }
    })
  }
}
