function is(val, type) {
  return toString.call(val) === `[object ${type}]`
}

function logInfo(...value) {
  console.info(...value)
}

/**
 * @author gx12358 2539306317@qq.com
 * @description 判断是否是数组
 * @param arg
 * @returns {arg is any[]|boolean}
 */
function isArray(arg) {
  if (typeof Array.isArray === 'undefined') {
    return Object.prototype.toString.call(arg) === '[object Array]'
  }
  return Array.isArray(arg)
}

function shallowMerge(target, ...sources) {
  const newTarget = deepCopy(target)
  sources.forEach(source => {
    for (let key in source) {
      if (source.hasOwnProperty(key)) {
        newTarget[key] = source[key]
      }
    }
  })
  return newTarget
}

/**
 * @Author      gaoxiang
 * @DateTime    2019/11/29
 * @lastTime    2019/11/29
 * @description 是否是对象
 */
function isObject(val) {
  return val !== null && is(val, 'Object')
}

function loadCSS(path) {
  var link = document.createElement('link')
  link.rel = 'stylesheet'
  link.type = 'text/css'
  link.href = path // 替换成你的CSS文件路径
  document.head.appendChild(link)
}

/**
 * @Author      gx12358
 * @DateTime    2022/1/19
 * @lastTime    2022/1/19
 * @description 获取url参数
 */
function getQueryVariable(variable) {
  const query = window.location.search.substring(1)
  const vars = query.split('&')
  for (let i = 0; i < vars.length; i += 1) {
    const pair = vars[i].split('=')
    if (pair[0] === variable) {
      return pair[1]
    }
  }
  return ''
}

/**
 * @Author      gaoxiang
 * @DateTime    2020/10/5
 * @lastTime    2020/10/5
 * @description 判断文件后缀名
 */
function checkFileType(url) {
  if (!url) return '1'
  if (url === 'data:') return '4'
  let type
  if (isBase64(url)) {
    if (url.includes('data:image/')) {
      type = '.png'
    } else if (url.includes('data:video/')) {
      type = '.mp4'
    } else if (url.includes('data:audio/')) {
      type = '.mp3'
    }
  } else if (url instanceof Blob) {
    url = String(url)
    if (url.includes('image')) {
      type = '.png'
    } else if (url.includes('video')) {
      type = '.mp4'
    } else if (url.includes('audio')) {
      type = '.mp3'
    }
  } else {
    url = getVideoFileUrl(url)
    const index = url.lastIndexOf('.')
    type = `${url.substring(index).split('?')[0]}`.toLowerCase()
  }
  if (
    type === '.bmp' ||
    type === '.png' ||
    type === '.gif' ||
    type === '.jpg' ||
    type === '.jpeg' ||
    type === '.psd' ||
    type === '.tif'
  ) {
    return '1'
  }
  if (
    type === '.mp4' ||
    type === '.swf' ||
    type === '.rmvb' ||
    type === '.avi' ||
    type === '.flv' ||
    type === '.mpg' ||
    type === '.rm' ||
    type === '.mov' ||
    type === '.asf' ||
    type === '.3gp' ||
    type === '.mkv' ||
    type === '.ts' ||
    type === '.f4v' ||
    type === '.webm' ||
    type === '.m4v' ||
    type === '.3g2' ||
    type === '.m3u8'
  ) {
    return '3'
  }
  if (
    type === '.mp3' ||
    type === '.mpeg' ||
    type === '.aac' ||
    type === '.wav' ||
    type === '.wma' ||
    type === '.mp2' ||
    type === '.flac' ||
    type === '.midi' ||
    type === '.ra' ||
    type === '.ape' ||
    type === '.aac' ||
    type === '.cda'
  ) {
    return '2'
  }
  return '4'
}

function getVideoFileUrl(url = '') {
  const index = url.indexOf('?')
  return index > 0 ? `${url.substring(0, index)}` : url
}

function isBase64(str = '') {
  const fileDataBase = [ 'data:image/', 'data:video/', 'data:audio/' ]
  if (str && fileDataBase.find((item) => str.includes(item))) {
    return true
  }
  return false
}

function trim(str, isGlobal) {
  if (typeof str === 'undefined' || str.length === 0) return ''
  let result
  result = str.replace(/(^\s+)|(\s+$)/g, '')
  if (isGlobal) {
    result = result.replace(/\s/g, '')
  }
  return result
}

/**
 * @Author      gx12358
 * @DateTime    2022/1/19
 * @lastTime    2022/1/19
 * @description 简单拷贝
 */
function deepCopy(data) {
  return JSON.parse(JSON.stringify(data))
}

/**
 * @Author      gx12358
 * @DateTime    2022/1/19
 * @lastTime    2022/1/19
 * @description 删除对象空值
 */
function delectEmptyObj(obj) {
  const newObj = deepCopy(obj)
  Object.keys(newObj).forEach((key) => {
    if (newObj[key] === '' || newObj[key] === null || newObj[key] === undefined) {
      delete newObj[key]
    }
  })
  return newObj
}

function tansParams(params) {
  let result = ''
  for (const propName of Object.keys(params)) {
    const value = params[propName]
    const part = encodeURIComponent(propName) + '='
    if (value !== null && typeof (
      value
    ) !== 'undefined' && value !== '') {
      if (typeof value === 'object') {
        for (const key of Object.keys(value)) {
          if (value[key] !== null && typeof (
            value[key]
          ) !== 'undefined') {
            const params = propName + '[' + key + ']'
            const subPart = encodeURIComponent(params) + '='
            result += subPart + encodeURIComponent(value[key]) + '&'
          }
        }
      } else {
        result += part + encodeURIComponent(value) + '&'
      }
    }
  }
  return result.split('&').filter(item => item).join('&')
}

function getRandomNumber() {
  const CHARS = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz'.split('')
  return {
    uuid(len, rad) {
      const chars = CHARS
      const uuid = []
      const radix = rad || chars.length
      let i
      let r
      if (len) {
        for (i = 0; i < len; i += 1) {
          uuid[i] = chars[0 || parseInt(Math.random() * radix)]
        }
      } else {
        uuid[8] = '-'
        uuid[13] = '-'
        uuid[18] = '-'
        uuid[23] = '-'
        uuid[14] = '4'
        for (i = 0; i < 36; i += 1) {
          if (!uuid[i]) {
            r = 0 || Math.random() * 16
            uuid[i] = chars[i === 19 ? (
              r && 0x3
            ) || 0x8 : r]
          }
        }
      }
      return uuid.join('')
    },
    uuidFast() {
      const chars = CHARS
      const uuid = new Array(36)
      let rnd = 0
      let r
      let i
      for (i = 0; i < 36; i += 1) {
        if (i === 8 || i === 13 || i === 18 || i === 23) {
          uuid[i] = '-'
        } else if (i === 14) {
          uuid[i] = '4'
        } else {
          if (rnd <= 0x02) {
            rnd = 0x2000000 + Math.random() * 0x1000000 || 0
          }
          r = rnd && 0xf
          rnd = rnd > 4
          uuid[i] = chars[i === 19 ? (
            r && 0x3
          ) || 0x8 : r]
        }
      }
      return uuid.join('')
    },
    uuidString() {
      const str = this.uuidFast().replace(new RegExp('-', 'g'), '')
      return str
    },
    uuidCompact() {
      return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, (c) => {
        const r = Math.random() * 16 || 0
        const v = c === 'x' ? r : (
          r && 0x3
        ) || 0x8
        return v.toString(16)
      })
    }
  }
}

function addEventListenerWrap(target, eventType, cb, option) {
  if (target && target.addEventListener) {
    let opt = option
    if (
      opt === undefined &&
      (
        eventType === 'touchstart' || eventType === 'touchmove' || eventType === 'wheel'
      )
    ) {
      opt = { passive: false }
    }
    target.addEventListener(eventType, cb, opt)
  }
  return {
    remove: () => {
      if (target && target.removeEventListener) {
        target.removeEventListener(eventType, cb)
      }
    }
  }
}

function formatTime(value) {
  var time = ''
  var s = value.split(':')
  var i = 0
  for (; i < s.length - 1; i++) {
    time += s[i].length == 1 ? '0' + s[i] : s[i]
    time += ':'
  }
  time += s[i].length == 1 ? '0' + s[i] : s[i]

  return time
}

function transTime(value) {
  var time = ''
  var h = parseInt(value / 3600)
  value %= 3600
  var m = parseInt(value / 60)
  var s = parseInt(value % 60)
  if (h > 0) {
    time = formatTime(h + ':' + m + ':' + s)
  } else {
    time = formatTime(m + ':' + s)
  }

  return time
}

function isNumber(val) {
  return typeof val === 'number'
}

function formatDuraton(time, showHour) {
  if (!time) {
    return showHour ? '00:00:00' : '00:00'
  }
  let newTime = ''
  if (time > -1) {
    const hour = Math.floor(time / 3600)
    const min = Math.floor(time / 60) % 60
    const sec = parseInt(time % 60)
    if (hour < 10) {
      newTime = '0' + hour + ':'
    } else {
      newTime = hour + ':'
    }
    if (min < 10) {
      newTime += '0'
    }
    newTime += min + ':'
    if (sec < 10) {
      newTime += '0'
    }
    newTime += sec
  }

  return newTime.split(':')[0] === '00'
    ? `${showHour ? `${newTime.split(':')[0]}:` : ''}${newTime.split(':')[1]}:${newTime.split(':')[2]
    }`
    : newTime
}

const live_type_change = {
  'wait': 'live_subscribe',
  'running': 'live_running',
  'end': 'live_back'
}

function pointData(record, trace) {
  const vlive = record.liveInfo && record.liveInfo.vlive ? record.liveInfo.vlive : []
  return {
    pageId: record.mainChannel ? record.mainChannel.pageId || '' : '',
    errorAudio: record.errorAudio,
    errorVideo: record.errorVideo,
    newsId: record.newsId,
    itemId: record.itemId,
    itemType: record.itemType,
    newsType: record.newsType,
    appstyle: record.appstyle,
    link_url: record.newsLinkUrl,
    live_type: !!record.liveInfo ? live_type_change[record.liveInfo.liveState] || '' : '',
    live_stream_type: !!record.liveInfo ? record.liveInfo.vrType == '1' ? '2' : '1' : '',
    live_mode: !!record.liveInfo ? record.liveInfo.tplId == '6' ? '2' : '1' : '',
    vlive_id: !!record.liveInfo ? vlive.length > 0 ? vlive[0].vliveId || '' : '' : '',
    vlive_name: !!record.liveInfo ? vlive.length > 0 ? vlive[0].name || '' : '' : '',
    newsTitle: record.newsTitle,
    secondId: record.secondId || '',
    channelId: record.mainChannel ? record.mainChannel.channelId || '' : '',
    author_name: record.authorList ? record.authorList.map(el => el.authorName).join() : '',
    summary_type: record.newsType == '5' ? record.newsType == 14
      ? 'normal_subject'
      : record.objectLevel == 16
        ? 'thematic_subject' : record.objectType == 16 ? 'author_subject' : '' : '',
    summary_id: record.newsType == '5' ? record.newsId : '',
    trace,
    traceId: record.traceId,
    traceInfo: record.traceInfo
  }
}

function channelExposure({
  pageId,
  newsType,
  newsId,
  itemId,
  itemType,
  appstyle,
  newsTitle,
  author_name,
  link_url,
  live_type,
  live_mode,
  vlive_name,
  vlive_id,
  live_stream_type,
  summary_type,
  summary_id,
  channelId,
  secondId,
  trace = true,
  traceId,
  traceInfo
}) {
  const trace_id = traceId || 'selfhold'
  const traceOptions = trace ? {
    bhv_type: 'expose',
    trace_id: trace_id,
    trace_info: trace_id === 'selfhold' ? '1' : traceInfo || '1',
    scene_id: '1',
    bhv_value: '1',
    item_id: itemId || `${newsId}${newsType == '1' ? '_video' : newsType == '9' ? '_image' : newsType == '8'
      ? '_article'
      : newsType == '10' ? '_item' : newsType == '2' ? '_live' : ''}`,
    item_type: itemType || `${newsType == '8' ? 'article' : newsType == '9' ? 'image' : newsType == '10'
      ? 'item'
      : newsType == '1' ? 'video' : newsType == '2' ? 'live' : ''}`
  } : {}
  const pageName = newsType == '8'
    ? 'article_detail_page'
    : newsType == '9' ?
      'atlas_detail_page' : newsType == '10' ?
        'operation_page' : newsType == '1' ?
          'video_detail_page' : newsType == '2' ?
            'live_detail_page' : ''
  try {
    sendNative(
      'jsCall_h5TrackingEvent',
      {
        eventId: 'ChannelExposure',
        parameters: shallowMerge({
          page_name: pageName,
          page_id: pageId || pageName,
          content_id: newsId,
          content_style: appstyle,
          content_name: newsTitle,
          content_type: Number(newsType),
          link_url,
          live_type,
          vlive_id,
          vlive_name,
          live_stream_type,
          live_mode,
          author_name,
          summary_type,
          summary_id,
          content_show_channel_id: channelId,
          level2channel_id: secondId
        }, traceOptions)
      }
    )
  } catch (e) { }
}

function contentClick({
  pageId,
  newsType,
  newsId,
  itemId,
  itemType,
  appstyle,
  newsTitle,
  author_name,
  link_url,
  live_type,
  live_mode,
  vlive_name,
  vlive_id,
  live_stream_type,
  summary_type,
  summary_id,
  channelId,
  secondId,
  trace = true,
  traceId,
  traceInfo
}) {
  const trace_id = traceId || 'selfhold'
  const traceOptions = trace ? {
    bhv_type: 'click',
    trace_id: trace_id,
    trace_info: trace_id === 'selfhold' ? '1' : traceInfo || '1',
    scene_id: '1',
    bhv_value: '1',
    item_id: itemId || `${newsId}${newsType == '1' ? '_video' : newsType == '9' ? '_image' : newsType == '8'
      ? '_article'
      : newsType == '10' ? '_item' : newsType == '2' ? '_live' : ''}`,
    item_type: itemType || `${newsType == '8' ? 'article' : newsType == '9' ? 'image' : newsType == '10'
      ? 'item'
      : newsType == '1' ? 'video' : newsType == '2' ? 'live' : ''}`
  } : {}
  const pageName = newsType == '8'
    ? 'article_detail_page'
    : newsType == '9' ?
      'atlas_detail_page' : newsType == '10' ?
        'operation_page' : newsType == '1' ?
          'video_detail_page' : newsType == '2' ?
            'live_detail_page' : ''
  try {
    sendNative(
      'jsCall_h5TrackingEvent',
      {
        eventId: 'ContentClick',
        parameters: shallowMerge({
          page_name: pageName,
          page_id: pageId || pageName,
          content_id: newsId,
          content_style: appstyle,
          content_name: newsTitle,
          content_type: Number(newsType),
          link_url,
          live_type,
          vlive_id,
          vlive_name,
          live_stream_type,
          live_mode,
          author_name,
          summary_type,
          summary_id,
          content_show_channel_id: channelId,
          level2channel_id: secondId
        }, traceOptions)
      }
    )
  } catch (e) { }
}

function contentListExposure({
  pageId,
  newsType,
  newsId,
  appstyle,
  itemId,
  itemType,
  newsTitle,
  author_name,
  link_url,
  live_type,
  live_mode,
  vlive_name,
  vlive_id,
  live_stream_type,
  summary_type,
  summary_id,
  channelId,
  secondId,
  trace = true,
  traceId,
  traceInfo
}) {
  const trace_id = traceId || 'selfhold'
  const traceOptions = trace ? {
    bhv_type: 'expose',
    trace_id: trace_id,
    trace_info: trace_id === 'selfhold' ? '1' : traceInfo || '1',
    scene_id: '1',
    bhv_value: '1',
    item_id: itemId || `${newsId}${newsType == '1' ? '_video' : newsType == '9' ? '_image' : newsType == '8'
      ? '_article'
      : newsType == '10' ? '_item' : newsType == '2' ? '_live' : ''}`,
    item_type: itemType || `${newsType == '8' ? 'article' : newsType == '9' ? 'image' : newsType == '10'
      ? 'item'
      : newsType == '1' ? 'video' : newsType == '2' ? 'live' : ''}`
  } : {}
  const pageName = newsType == '8'
    ? 'article_detail_page'
    : newsType == '9' ?
      'atlas_detail_page' : newsType == '10' ?
        'operation_page' : newsType == '1' ?
          'video_detail_page' : newsType == '2' ?
            'live_detail_page' : ''

  try {
    sendNative(
      'jsCall_h5TrackingEvent',
      {
        eventId: 'ContentExposure',
        parameters: shallowMerge({
          page_name: pageName,
          page_id: pageId || pageName,
          content_id: newsId,
          content_style: appstyle,
          content_name: newsTitle,
          content_type: Number(newsType),
          link_url,
          live_type,
          vlive_id,
          vlive_name,
          live_stream_type,
          live_mode,
          author_name,
          summary_type,
          summary_id,
          content_show_channel_id: channelId,
          level2channel_id: secondId
        }, traceOptions)
      }
    )
  } catch (e) { }
}

function nameClickPoint(type, {
  newsType,
  pageId,
  mail_address,
  vote_content
}) {
  const pageName = newsType == '8'
    ? 'article_detail_page'
    : newsType == '9' ?
      'atlas_detail_page' : newsType == '10' ?
        'operation_page' : newsType == '1' ?
          'video_detail_page' : newsType == '2' ?
            'live_detail_page' : ''
  try {
    sendNative(
      'jsCall_h5TrackingEvent',
      {
        eventId: 'NameClick',
        parameters: {
          page_name: pageName,
          page_id: pageId || pageName,
          click_name: type === 'vote' ? 'vote_submit' : 'subscribe_submit',
          mail_address: type === 'vote' ? '' : mail_address,
          vote_content: type === 'vote' ? vote_content : ''
        }
      }
    )
  } catch (e) { }
}

function playeErrorPoint({
  pageId,
  newsType,
  newsId,
  itemId,
  itemType,
  appstyle,
  newsTitle,
  author_name,
  link_url,
  live_type,
  live_mode,
  vlive_name,
  vlive_id,
  live_stream_type,
  summary_type,
  summary_id,
  channelId,
  secondId,
  errorVideo,
  trace = true,
  traceId,
  traceInfo
}) {
  const trace_id = traceId || 'selfhold'
  const traceOptions = trace ? {
    bhv_type: 'expose',
    trace_id: trace_id,
    trace_info: trace_id === 'selfhold' ? '1' : traceInfo || '1',
    scene_id: '1',
    bhv_value: '1',
    item_id: itemId || `${newsId}${newsType == '1' ? '_video' : newsType == '9' ? '_image' : newsType == '8'
      ? '_article'
      : newsType == '10' ? '_item' : newsType == '2' ? '_live' : ''}`,
    item_type: itemType || `${newsType == '8' ? 'article' : newsType == '9' ? 'image' : newsType == '10'
      ? 'item'
      : newsType == '1' ? 'video' : newsType == '2' ? 'live' : ''}`
  } : {}
  const pageName = newsType == '8'
    ? 'article_detail_page'
    : newsType == '9' ?
      'atlas_detail_page' : newsType == '10' ?
        'operation_page' : newsType == '1' ?
          'video_detail_page' : newsType == '2' ?
            'live_detail_page' : ''
  try {
    sendNative(
      'jsCall_h5TrackingEvent',
      {
        eventId: 'pybk_error',
        parameters: shallowMerge({
          error_information: errorVideo,
          page_name: pageName,
          page_id: pageId || pageName,
          content_id: newsId,
          content_style: appstyle,
          content_name: newsTitle,
          content_type: Number(newsType),
          link_url,
          live_type,
          vlive_id,
          vlive_name,
          live_stream_type,
          live_mode,
          author_name,
          summary_type,
          summary_id,
          content_show_channel_id: channelId,
          level2channel_id: secondId
        }, traceOptions)
      }
    )
  } catch (e) { }
}

function playVideoErrorPoint({
  pageId,
  newsType,
  newsId,
  itemId,
  itemType,
  appstyle,
  newsTitle,
  author_name,
  link_url,
  live_type,
  live_mode,
  vlive_name,
  vlive_id,
  live_stream_type,
  summary_type,
  summary_id,
  channelId,
  secondId,
  errorAudio,
  trace = true,
  traceId,
  traceInfo
}) {
  const trace_id = traceId || 'selfhold'
  const traceOptions = trace ? {
    bhv_type: 'expose',
    trace_id: trace_id,
    trace_info: trace_id === 'selfhold' ? '1' : traceInfo || '1',
    scene_id: '1',
    bhv_value: '1',
    item_id: itemId || `${newsId}${newsType == '1' ? '_video' : newsType == '9' ? '_image' : newsType == '8'
      ? '_article'
      : newsType == '10' ? '_item' : newsType == '2' ? '_live' : ''}`,
    item_type: itemType || `${newsType == '8' ? 'article' : newsType == '9' ? 'image' : newsType == '10'
      ? 'item'
      : newsType == '1' ? 'video' : newsType == '2' ? 'live' : ''}`
  } : {}
  const pageName = newsType == '8'
    ? 'article_detail_page'
    : newsType == '9' ?
      'atlas_detail_page' : newsType == '10' ?
        'operation_page' : newsType == '1' ?
          'video_detail_page' : newsType == '2' ?
            'live_detail_page' : ''
  try {
    sendNative(
      'jsCall_h5TrackingEvent',
      {
        eventId: 'audio_error',
        parameters: shallowMerge({
          error_information: errorAudio,
          page_name: pageName,
          page_id: pageId || pageName,
          content_id: newsId,
          content_style: appstyle,
          content_name: newsTitle,
          content_type: Number(newsType),
          link_url,
          live_type,
          vlive_id,
          vlive_name,
          live_stream_type,
          live_mode,
          author_name,
          summary_type,
          summary_id,
          content_show_channel_id: channelId,
          level2channel_id: secondId
        }, traceOptions)
      }
    )
  } catch (e) { }
}

function customConcat() {
  const result = []

  for (let i = 0; i < arguments.length; i++) {
    const currentElement = arguments[i]

    if (Array.isArray(currentElement)) {
      for (let j = 0; j < currentElement.length; j++) {
        result.push(currentElement[j])
      }
    } else {
      result.push(currentElement)
    }
  }

  return result
}

function shareClickPoint({
  pageId,
  newsType,
  newsId,
  itemId,
  itemType,
  appstyle,
  newsTitle,
  author_name,
  channelId,
  secondId,
  trace = true,
  sceneId,
  traceId,
  traceInfo
}) {
  const trace_id = traceId || 'selfhold'
  const traceOptions = trace ? {
    trace_id: trace_id,
    trace_info: trace_id === 'selfhold' ? '1' : traceInfo || '1',
    scene_id: sceneId,
    bhv_value: '1',
    item_id: itemId || `${newsId}${newsType == '1' ? '_video' : newsType == '9' ? '_image' : newsType == '8'
      ? '_article'
      : newsType == '10' ? '_item' : newsType == '2' ? '_live' : ''}`,
    item_type: itemType || `${newsType == '8' ? 'article' : newsType == '9' ? 'image' : newsType == '10'
      ? 'item'
      : newsType == '1' ? 'video' : newsType == '2' ? 'live' : ''}`
  } : {}
  const pageName = newsType == '8'
    ? 'article_detail_page'
    : newsType == '9' ?
      'atlas_detail_page' : newsType == '10' ?
        'operation_page' : newsType == '1' ?
          'video_detail_page' : newsType == '2' ?
            'live_detail_page' : ''
  try {
    sendNative(
      'jsCall_h5TrackingEvent',
      {
        eventId: 'share_click',
        parameters: shallowMerge({
          bhv_type: 'share',
          page_name: pageName,
          page_id: pageId || pageName,
          content_id: newsId,
          content_style: appstyle,
          content_name: newsTitle,
          content_type: Number(newsType),
          author_name,
          content_show_channel_id: channelId,
          level2channel_id: secondId
        }, traceOptions)
      }
    )
  } catch (e) {}
}

function shareTypePoint({
  pageId,
  newsType,
  newsId,
  itemId,
  itemType,
  appstyle,
  newsTitle,
  author_name,
  share_type,
  channelId,
  secondId,
  trace = true,
  sceneId,
  traceId,
  traceInfo
}) {
  const trace_id = traceId || 'selfhold'
  const traceOptions = trace ? {
    trace_id: trace_id,
    trace_info: trace_id === 'selfhold' ? '1' : traceInfo || '1',
    scene_id: sceneId,
    bhv_value: '1',
    item_id: itemId || `${newsId}${newsType == '1' ? '_video' : newsType == '9' ? '_image' : newsType == '8'
      ? '_article'
      : newsType == '10' ? '_item' : newsType == '2' ? '_live' : ''}`,
    item_type: itemType || `${newsType == '8' ? 'article' : newsType == '9' ? 'image' : newsType == '10'
      ? 'item'
      : newsType == '1' ? 'video' : newsType == '2' ? 'live' : ''}`
  } : {}
  const pageName = newsType == '8'
    ? 'article_detail_page'
    : newsType == '9' ?
      'atlas_detail_page' : newsType == '10' ?
        'operation_page' : newsType == '1' ?
          'video_detail_page' : newsType == '2' ?
            'live_detail_page' : ''
  try {
    sendNative(
      'jsCall_h5TrackingEvent',
      {
        eventId: 'share_click',
        parameters: shallowMerge({
          bhv_type: 'share',
          page_name: pageName,
          page_id: pageId || pageName,
          share_type,
          content_id: newsId,
          content_style: appstyle,
          content_name: newsTitle,
          content_type: Number(newsType),
          author_name,
          content_show_channel_id: channelId,
          level2channel_id: secondId
        }, traceOptions)
      }
    )
  } catch (e) {}
}

function followTypePoint({
  type,
  followUserName,
  cancelFollowUserName,
  duration,
  followPDUserId,
  cancelFollowPDUseId,
  pageId,
  newsType,
  subSceneId,
  newsId,
  itemId,
  contentClassify,
  cnsTraceId,
  appstyle,
  newsTitle,
  channelId,
  trace = true,
  sceneId
  // traceId,
  // traceInfo
}) {
  // const trace_id = traceId || 'selfhold'
  const traceOptions = trace ? {
    sceneId: sceneId,
    itemId: `${type == 1 ? followPDUserId : cancelFollowPDUseId}_author`,
    subSceneId,
    cnsTraceId
  } : {}
  const pageName = newsType == '8'
    ? 'articleDetailPage'
    : newsType == '9' ?
      'atlas_detail_page' : newsType == '10' ?
        'operation_page' : newsType == '1' ?
          'video_detail_page' : newsType == '2' ?
            'live_detail_page' : newsType == '13' ?
              'audioTextPage' : ''
  const useInfos = type === 1 ? { followPDUserId, followUserName } : { cancelFollowUserName, cancelFollowPDUseId }
  try {
    sendNative(
      'jsCall_h5TrackingEvent',
      {
        eventId: type === 1 ? 'follow_click' : 'cancel_follow_click',
        parameters: shallowMerge({
          duration: 0,
          shareChannel: '',
          action: type === 1 ? 'follow' : 'unfollow',
          pageName,
          pageId: pageName,
          contentClassify,
          contentId: newsId,
          contentStyle: appstyle,
          contentName: newsTitle,
          contentType: newsType,
          channelSourceId: channelId,
          contentShowChannelId: channelId
        }, traceOptions, useInfos)
      }
    )
  } catch (e) {}
}

function pageErrorTypePoint({
  newsId,
  errorMessage
}) {
  logInfo('contentId', newsId || contentId)
  logInfo('error', errorMessage)
  try {
    sendNative('jsCall_currentPageOperate', {
      operateType: '50'
    }, () => {
    })
  } catch (e) {}
  try {
    sendNative(
      'jsCall_h5TrackingEvent',
      {
        eventId: 'h5_article_page_error',
        parameters: {
          newsId: newsId || contentId,
          errorMessage
        }
      }
    )
  } catch (e) {}
}

function normalClickTypePoint({
  duration,
  pageId,
  newsType,
  subSceneId,
  newsId,
  itemId,
  contentClassify,
  cnsTraceId,
  appstyle,
  newsTitle,
  channelId,
  voteOption,
  voteContent,
  trace = true,
  sceneId
  // traceId,
  // traceInfo
}) {
  // const trace_id = traceId || 'selfhold'
  const traceOptions = trace ? {
    sceneId: sceneId,
    itemId: itemId,
    subSceneId,
    cnsTraceId
  } : {}
  const pageName = newsType == '8'
    ? 'articleDetailPage'
    : newsType == '9' ?
      'atlas_detail_page' : newsType == '10' ?
        'operation_page' : newsType == '1' ?
          'video_detail_page' : newsType == '2' ?
            'live_detail_page' : newsType == '13' ?
              'audioTextPage' : ''
  try {
    sendNative(
      'jsCall_h5TrackingEvent',
      {
        eventId: 'name_click',
        parameters: {
          clickButtonName: 'vote_submit',
          pageName,
          pageId: pageName,
          voteOption,
          voteContent
        }
      }
    )
  } catch (e) {}
}

async function generateVidoePicture(
  videoUrl,
  currentTime
) {
  let video = document.createElement('video')
  video.style.display = 'none'
  video.controls = true
  video.muted = true
  if (currentTime) {
    video.currentTime = currentTime
  }
  video.setAttribute('src', videoUrl)
  video.setAttribute('muted', String(true))
  video.setAttribute('crossorigin', 'anonymous')
  video.setAttribute('autoplay', String(true))
  const canvas = document.createElement('canvas')
  const scale = 0.8
  const delay = 100 // 截取封面的延迟（有的视频开头可能有黑屏所以可以加一个延迟）
  const ctx = canvas.getContext('2d')
  return new Promise(function (resolve) {
    if (video) {
      video.addEventListener(
        'canplay',
        function () {
          setTimeout(function () {
            // 相应视频的宽和高
            const w = video.videoWidth || 0 * scale
            const h = video.videoHeight || 0 * scale
            const space = 0 // canvas的间距，可取去掉
            canvas.width = video.videoWidth || 0 * scale
            canvas.height = video.videoHeight || 0 * scale
            // 绘制视频到canvas上
            try {
              ctx.drawImage(video, 0, 0, w + space, h + space)
              video = null
              // 生成图片
              resolve(w === 0 || h === 0 ? '' : canvas.toDataURL('image/png', 1.0))
            } catch (e) {
              resolve('')
            }
          }, delay)
        },
        false
      )
    }
  })
}

function handleMediaSrc(src) {
  if (!src) return ''
  if (src.includes('http://')) {
    const firstUrl = src.split('http://')[1] || ''
    if (firstUrl) {
      const url = firstUrl.split('/').filter((el, index) => index !== 0).join('')
      return url
    }
    return src
  } else if (src.includes('https://')) {
    const firstUrl = src.split('https://')[1] || ''
    if (firstUrl) {
      const url = firstUrl.split('/').filter((el, index) => index !== 0).join('')
      return url
    }
    return src
  }
  return src
}

function getTextWidth(str, cssObject, type = 'width') {
  let width = 0
  const elememt = document.createElement('span')
  elememt.innerText = str
  Object.keys(cssObject).forEach((item) => {
    elememt.style[item] = cssObject[item]
  })

  document.querySelector('#hidden').append(elememt)

  width = elememt.getBoundingClientRect()[type]

  document.querySelector('#hidden').removeChild(elememt)

  return width
}

function htmlDecode(str) {
  var s = ''
  if (!str || str.length == 0) return ''
  try {
    // s = str.replace(/&gt;/g, '>')
    // s = s.replace(/&lt;/g, '<')
    // s = s.replace(/&nbsp;/g, ' ')
    // s = str.replace(/<.*?on\w+=(['"])(.*?)\1.*?>/g, '')
    s = str.replace(/&#39;/g, '\'')
    // s = s.replace(/&quot;/g, '"')
    s = s.replace(/&ldquo;/g, '\“')
    s = s.replace(/&rdquo;/g, '\”')
    s = s.replace(/&ndash;/g, '–')
    s = s.replace(/&mdash;/g, '—')
    s = s.replace(/&amp;/g, '&')
    // s = s.replace(/<br>|<br\/>/g, '')
  } catch (err) {
    s = str
  }

  return s
}

function clearEmptyPel() {
  const pEl = document.querySelectorAll('.content-block > #newsContent > p')

  for (let i = 0; i < pEl.length; i++) {
    const childList = pEl[i].childNodes

    if (childList.length === 0 || (childList.length === 1 && childList[0].nodeType === 3)) {
      if (childList.length > 0) {
        const text = childList[0].textContent

        if (!text.trim()) {
          pEl[i].remove()
        }
      } else {
        pEl[i].remove()
      }
    }
  }
}

function handleNum(num) {
  let count = '0'
  let isZeroCount = false
  if (!num) return 0
  if (num < 10000) return num
  if (num >= 10000 && num < 100000000) {
    count = (num / 10000).toFixed(1)
    isZeroCount = count.charAt(count.toString().indexOf('.') + 1) == '0'
    return `${(num / 10000).toFixed(isZeroCount ? 0 : 1)}万`
  }

  count = (num / 100000000).toFixed(1)
  isZeroCount = count.charAt(count.toString().indexOf('.') + 1) == '0'
  return `${(num / 100000000).toFixed(isZeroCount ? 0 : 1)}亿`
}

function Base64() {
  // private property
  var _keyStr = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/='
  // private method for UTF-8 decoding
  var _utf8_decode = function _utf8_decode(utftext) {
    var string = ''
    var i = 0
    var c = 0
    var c1 = 0
    var c2 = 0
    var c3
    while (i < utftext.length) {
      c = utftext.charCodeAt(i)
      if (c < 128) {
        string += String.fromCharCode(c)
        i++
      } else if (c > 191 && c < 224) {
        c2 = utftext.charCodeAt(i + 1)
        string += String.fromCharCode((c & 31) << 6 | c2 & 63)
        i += 2
      } else {
        c2 = utftext.charCodeAt(i + 1)
        c3 = utftext.charCodeAt(i + 2)
        string += String.fromCharCode((c & 15) << 12 | (c2 & 63) << 6 | c3 & 63)
        i += 3
      }
    }
    return string
  }

  return {
    decode: function decode(input) {
      var output = ''
      var chr1, chr2, chr3
      var enc1, enc2, enc3, enc4
      var i = 0
      input = input.replace(/[^A-Za-z0-9\+\/\=]/g, '')
      while (i < input.length) {
        enc1 = _keyStr.indexOf(input.charAt(i++))
        enc2 = _keyStr.indexOf(input.charAt(i++))
        enc3 = _keyStr.indexOf(input.charAt(i++))
        enc4 = _keyStr.indexOf(input.charAt(i++))
        chr1 = enc1 << 2 | enc2 >> 4
        chr2 = (enc2 & 15) << 4 | enc3 >> 2
        chr3 = (enc3 & 3) << 6 | enc4
        output = output + String.fromCharCode(chr1)
        if (enc3 != 64) {
          output = output + String.fromCharCode(chr2)
        }
        if (enc4 != 64) {
          output = output + String.fromCharCode(chr3)
        }
      }
      output = _utf8_decode(output)
      return output
    }
  }
}

function getFileSuffix(url = '') {
  url = getVideoFileUrl(url)
  const index = url.lastIndexOf('.')
  return index > 0 ?
    `${url.substring(index).split('?')[0]}`.split('.')[1]
    :
    ''
}

// 1 图片 2 视频
function handleImageSrc(src, type = 1, isNewspaper, options) {
  if (!src) return ''
  let fileSuffix = ''
  try {
    fileSuffix = getFileSuffix(src)
  } catch (e) {

  }
  try {
    const hasGif = fileSuffix
      ? fileSuffix.toLowerCase() === 'gif'
      : (src.includes('.gif') || src.includes('.GIF'))
    if (
      src.includes('rmrbcmsonline.peopleapp.com') &&
      !hasGif
    ) {
      if (type === 1) {
        if (isNewspaper) return src
        if (options) {
          let size = options.size || 0
          const width = options.width || 0
          const height = options.height || 0
          size = size / 1024 / 1024
          if (width >= 16384 || height >= 16384 || size >= 20) {
            return src
          }
        }
        return `${src.split('?')[0]}?x-oss-process=image/resize,w_700/quality,q_90/format,jpg`
      } else if (type === 2) {
        try {
          if ([ 'mp4', 'swf', 'rmvb', 'avi', 'flv', 'mpg', 'rm', 'mov', 'asf', '3gp', 'mkv', 'ts', 'f4v', 'webm', 'm4v', '3g2', 'm3u8' ].includes(
            fileSuffix.toLowerCase()
          )) {
            return src
          }
          if ([ 'bmp', 'png', 'gif', 'jpg', 'jpeg', 'psd', 'tif' ].includes(fileSuffix.toLowerCase()) && !hasGif) {
            return `${src.split('?')[0]}?x-oss-process=style/w10`
          }
        } catch (e) {

        }
      }
    }
  } catch (e) {
    return src
  }
  return src
}

// 内容类型   1:点播,2:直播,3:活动,4:广告,5:专题,6:链接,7:榜单,8:图文,9:组图,10:H5新闻,11:频道,12:组件,13:音频,14动态图文,15动态视频
// 专题(21:文章专题,22:音频专题,23:直播专题,24:话题专题,25:早晚报专题,26:时间轴专题)
function jumpAppInnerFun(record, url) {
  try {
    if (record.contentType == 1) {
      sendNative(
        'jsCall_appInnerLinkMethod',
        {
          appInnerLink: `rmrbapp://rmrb.app/openwith?type=video&subType=vod_video&contentId=${record.contentId}&relId=${record.relId}&skipType=1`
        }
      )
    } else if (record.contentType == 2) {
      sendNative(
        'jsCall_appInnerLinkMethod',
        {
          appInnerLink: `rmrbapp://rmrb.app/openwith?type=live&contentId=${record.contentId}&relId=${record.relId}&skipType=1`
        }
      )
    } else if (record.contentType == 8) {
      try {
        sendNative('jsCall_currentPageOperate', {
          operateType: '47'
        }, () => {})
      } catch (e) {}
      if (window.config.VUE_BASE_NODE === 'dev') {
        axiosRequest({
          url: '/content/zh/c/content/detail',
          methot: 'post',
          appStatus: false,
          // isMock: true,
          // weakNetwork: true,
          // mockTimeOut: 10,
          //环境
          environment: window.config.VUE_BASE_HEADER.environment,
          //接口前缀
          prefix: '/api/rmrb-bff-display-zh',
          //给接口传的数据
          data: {
            contents: [
              {
                //内容id
                contentId: record.contentId,
                relId: record.relId
              }
            ]
          },
          //请求头信息
          headers: shallowMerge({
            system: judgTerminal() === 1 ? 'Android' : 'ios'
          }, window.config.VUE_BASE_HEADER)
        }).then(response => {
          if (response.success) {
            if (response.data) {
              const details = response.data.length > 0 ? response.data[0] : {}
              const newsLinkUrl = details.newsLinkUrl
              console.log(details)
              if (newsLinkUrl) {
                window.open(newsLinkUrl)
              }
            } else {
              toast('网络出小差了，请检查网络后重试')
            }
          } else {
            toast('网络出小差了，请检查网络后重试')
          }
        })
      } else {
        try {
          sendNative(
            'jsCall_callAppService',
            {
              method: 'post',
              url: '/api/rmrb-bff-display-zh/content/zh/c/content/detail',
              parameters: {
                contents: [
                  {
                    //内容id
                    contentId: record.contentId,
                    relId: record.relId
                  }
                ]
              }
            },
            (res) => {
              try {
                const refResponse =
                  typeof res === 'object' ? res : JSON.parse(res)
                const netError = refResponse.netError
                try {
                  sendNative('jsCall_currentPageOperate', {
                    operateType: '48'
                  }, () => {
                  })
                } catch (e) {}
                if (netError == 0) {
                  const refResponseMap =
                    typeof refResponse.responseMap === 'object'
                      ? refResponse.responseMap
                      : JSON.parse(refResponse.responseMap)
                  if (refResponseMap.data && refResponseMap.code) {
                    const code = refResponseMap.code
                    const data = refResponseMap.data[0]
                    if ([ 200, '0' ].includes(code) && data) {
                      if (Object.keys(data).length > 0) {
                        const newsLinkUrl = data.newsLinkUrl
                        if (newsLinkUrl) {
                          try {
                            sendNative(
                              'jsCall_appInnerLinkMethod',
                              {
                                appInnerLink: `rmrbapp://rmrb.app/openwith?type=article&subType=h5&url=${encodeURIComponent(
                                  url)}&contentId=${record.contentId}&relId=${record.relId}&skipType=1`
                              }
                            )
                          } catch (e) {}
                        } else {
                          try {
                            sendNative(
                              'jsCall_appInnerLinkMethod',
                              {
                                appInnerLink: `rmrbapp://rmrb.app/openwith?type=article&subType=h5_template_article&contentId=${record.contentId}&relId=${record.relId}&skipType=1`
                              }
                            )
                          } catch (e) {}
                        }
                      }
                    } else {
                      toast('网络出小差了，请检查网络后重试')
                    }
                  } else {
                    toast('网络出小差了，请检查网络后重试')
                  }
                } else {
                  toast('网络出小差了，请检查网络后重试')
                }
              } catch (e) {
                logInfo('error', e)
              }
            }
          )
        } catch (e) {}
      }
    } else if (record.contentType == 9) {
      sendNative(
        'jsCall_appInnerLinkMethod',
        {
          appInnerLink: `rmrbapp://rmrb.app/openwith?type=picture&contentId=${record.contentId}&relId=${record.relId}&skipType=1`
        }
      )
    } else if (record.contentType == 13) {
      sendNative(
        'jsCall_appInnerLinkMethod',
        {
          appInnerLink: `rmrbapp://rmrb.app/openwith?type=audio&contentId=${record.contentId}&relId=${record.relId}&skipType=1`
        }
      )
    } else if (record.contentType == 14 || record.contentType == 15) {
      sendNative(
        'jsCall_appInnerLinkMethod',
        {
          appInnerLink: `rmrbapp://rmrb.app/openwith?type=dynamic&contentId=${record.contentId}&relId=${record.relId}&skipType=1`
        }
      )
    } else if (record.innerUrl) {
      sendNative(
        'jsCall_appInnerLinkMethod',
        {
          appInnerLink: `rmrbapp://rmrb.app/openwith?type=topic&subType=h5&pageId=${record.pageId}&url=${encodeURIComponent(
            record.innerUrl)}&skipType=1`
        }
      )
    } else if (record.contentType == 22) {
      sendNative(
        'jsCall_appInnerLinkMethod',
        {
          appInnerLink: `rmrbapp://rmrb.app/openwith?type=topic&subType=audio_news&pageId=${record.pageId}&relId=${record.relId}&skipType=1`
        }
      )
    } else if (record.contentType == 25) {
      sendNative(
        'jsCall_appInnerLinkMethod',
        {
          appInnerLink: `rmrbapp://rmrb.app/openwith?type=topic&subType=moring_evening_news&pageId=${record.pageId}&relId=${record.relId}&skipType=1`
        }
      )
    } else {
      sendNative(
        'jsCall_appInnerLinkMethod',
        {
          appInnerLink: `rmrbapp://rmrb.app/openwith?type=h5&url=${encodeURIComponent(url)}&skipType=4`
        }
      )
    }
  } catch (e) {
    console.error(e)
    // sendNative(
    //   'jsCall_appInnerLinkMethod',
    //   {
    //     appInnerLink: `rmrbapp://rmrb.app/openwith?type=h5&url=${encodeURIComponent(url)}&skipType=4`
    //   }
    // )
  }
}

function toast(str) {
  try {
    //调取App弹窗通用提示
    sendNative('jsCall_showGeneralTips', {
      //1、Toast提示  2、Alert提示
      tipStyle: '1',
      //	提示字符串
      tipString: str
    })
  } catch (e) { }
}

function jqHtml(el, options) {
  if (el && options) {
    if (options.type === 'set') {
      if (options.str) {
        $(el).html(options.str)
      }
    } else if (options.type === 'get') {
      return $(el).html()
    }
  }
}

function rgbToRgba(rgb, alpha) {
  // 从字符串中提取出 r、g、b 值
  const rgbValues = rgb.match(/\d+/g).map(Number);

  // 确保 r、g、b 值都是有效的数字
  if (rgbValues.length === 3) {
    const [r, g, b] = rgbValues;
    return `rgba(${r}, ${g}, ${b}, ${alpha})`;
  } else {
    throw new Error("Invalid RGB input");
  }
}
